@@ -146,7 +146,6 @@ void ogs_timer_stop_debug(ogs_timer_t *timer, const char *file_line)
     manager = timer->manager;
     ogs_assert(manager);
     timer = ogs_timer_cycle(manager, timer);
-    ogs_assert(timer);
     if (!timer) {
         ogs_fatal("ogs_timer_stop() failed in %s", file_line);
         ogs_assert_if_reached();
@@ -200,6 +199,8 @@ void ogs_timer_mgr_expire(ogs_timer_mgr_t *manager)
         ogs_list_add(&list, &this->lnode);
     }
 
+    /* You should not perform a delete on a timer using ogs_timer_delete()
+     * in a callback function this->cb(). */
     ogs_list_for_each(&list, lnode) {
         this = ogs_rb_entry(lnode, ogs_timer_t, lnode);
         ogs_timer_stop(this);
