@@ -24,9 +24,11 @@ static void handle_nf_service(
 static void handle_smf_info(
         ogs_sbi_nf_instance_t *nf_instance, OpenAPI_smf_info_t *SmfInfo);
 static void handle_scp_info(
-        ogs_sbi_nf_instance_t *nf_instance, OpenAPI_scp_info_t *SeppInfo);
+        ogs_sbi_nf_instance_t *nf_instance, OpenAPI_scp_info_t *ScpInfo);
 static void handle_sepp_info(
         ogs_sbi_nf_instance_t *nf_instance, OpenAPI_sepp_info_t *SeppInfo);
+static void handle_amf_info(
+        ogs_sbi_nf_instance_t *nf_instance, OpenAPI_amf_info_t *AmfInfo);
 
 void ogs_nnrf_nfm_handle_nf_register(
         ogs_sbi_nf_instance_t *nf_instance, ogs_sbi_message_t *recvmsg)
@@ -256,7 +258,14 @@ void ogs_nnrf_nfm_handle_nf_profile(
         if (SmfInfoMap && SmfInfoMap->value)
             handle_smf_info(nf_instance, SmfInfoMap->value);
     }
+    if (NFProfile->amf_info)
+        handle_amf_info(nf_instance, NFProfile->amf_info);
 
+    OpenAPI_list_for_each(NFProfile->amf_info_list, node) {
+        OpenAPI_map_t *AmfInfoMap = node->data;
+        if (AmfInfoMap && AmfInfoMap->value)
+            handle_amf_info(nf_instance, AmfInfoMap->value);
+    }
     if (NFProfile->scp_info)
         handle_scp_info(nf_instance, NFProfile->scp_info);
     if (NFProfile->sepp_info)
@@ -608,6 +617,8 @@ static void handle_sepp_info(
     ogs_assert(nf_instance);
     ogs_assert(SeppInfo);
 
+    http.port = 0;
+    https.port = 0;
     http.presence = false;
     https.presence = false;
 
@@ -651,6 +662,100 @@ static void handle_sepp_info(
     }
 }
 
+static void handle_amf_info(
+        ogs_sbi_nf_instance_t *nf_instance, OpenAPI_amf_info_t *AmfInfo)
+{
+    ogs_sbi_nf_info_t *nf_info = NULL;
+    OpenAPI_list_t *GuamiList = NULL;
+    OpenAPI_guami_t *GuamiAmfInfoItem = NULL;
+    OpenAPI_list_t *TaiList = NULL;
+    OpenAPI_tai_t *TaiItem = NULL;
+    OpenAPI_list_t *TaiRangeList = NULL;
+    OpenAPI_tai_range_t *TaiRangeItem = NULL;
+    OpenAPI_list_t *TacRangeList = NULL;
+    OpenAPI_tac_range_t *TacRangeItem = NULL;
+    OpenAPI_lnode_t *node = NULL, *node2 = NULL;
+
+    ogs_assert(nf_instance);
+    ogs_assert(AmfInfo);
+
+    nf_info = ogs_sbi_nf_info_add(
+            &nf_instance->nf_info_list, OpenAPI_nf_type_AMF);
+    ogs_assert(nf_info);
+
+    nf_info->amf.amf_set_id = ogs_uint64_from_string(AmfInfo->amf_set_id);
+    nf_info->amf.amf_region_id = ogs_uint64_from_string(AmfInfo->amf_region_id);
+    GuamiList = AmfInfo->guami_list;
+
+    OpenAPI_list_for_each(GuamiList, node) {
+        GuamiAmfInfoItem = node->data;
+        if (GuamiAmfInfoItem) {
+            ogs_assert(nf_info->amf.num_of_guami < OGS_MAX_NUM_OF_SERVED_GUAMI);
+
+            if (GuamiAmfInfoItem->amf_id && GuamiAmfInfoItem->plmn_id &&
+                    GuamiAmfInfoItem->plmn_id->mnc &&
+                    GuamiAmfInfoItem->plmn_id->mcc) {
+
+                ogs_sbi_parse_guami(
+                        &nf_info->amf.guami[nf_info->amf.num_of_guami],
+                        GuamiAmfInfoItem);
+                nf_info->amf.num_of_guami++;
+            }
+        }
+    }
+
+    TaiList = AmfInfo->tai_list;
+    OpenAPI_list_for_each(TaiList, node) {
+        TaiItem = node->data;
+        if (TaiItem && TaiItem->plmn_id && TaiItem->tac) {
+            ogs_5gs_tai_t *nr_tai = NULL;
+            ogs_assert(nf_info->amf.num_of_nr_tai < OGS_MAX_NUM_OF_TAI);
+            nr_tai = &nf_info->amf.nr_tai[nf_info->amf.num_of_nr_tai];
+            ogs_assert(nr_tai);
+            ogs_sbi_parse_plmn_id(&nr_tai->plmn_id, TaiItem->plmn_id);
+            nr_tai->tac = ogs_uint24_from_string(TaiItem->tac);
+            nf_info->amf.num_of_nr_tai++;
+        }
+    }
+
+    TaiRangeList = AmfInfo->tai_range_list;
+    OpenAPI_list_for_each(TaiRangeList, node) {
+        TaiRangeItem = node->data;
+        if (TaiRangeItem && TaiRangeItem->plmn_id &&
+                TaiRangeItem->tac_range_list) {
+            ogs_assert(nf_info->amf.num_of_nr_tai_range <
+                    OGS_MAX_NUM_OF_TAI);
+
+            ogs_sbi_parse_plmn_id(
+                &nf_info->amf.nr_tai_range
+                    [nf_info->amf.num_of_nr_tai_range].plmn_id,
+                TaiRangeItem->plmn_id);
+
+            TacRangeList = TaiRangeItem->tac_range_list;
+            OpenAPI_list_for_each(TacRangeList, node2) {
+                TacRangeItem = node2->data;
+                if (TacRangeItem &&
+                        TacRangeItem->start && TacRangeItem->end) {
+                    int tac_index = nf_info->amf.nr_tai_range
+                        [nf_info->amf.num_of_nr_tai_range].num_of_tac_range;
+                    ogs_assert(tac_index < OGS_MAX_NUM_OF_TAI);
+
+                    nf_info->amf.nr_tai_range
+                        [nf_info->amf.num_of_nr_tai_range].start[tac_index] =
+                                ogs_uint24_from_string(TacRangeItem->start);
+                    nf_info->amf.nr_tai_range
+                        [nf_info->amf.num_of_nr_tai_range].end[tac_index] =
+                                ogs_uint24_from_string(TacRangeItem->end);
+
+                    nf_info->amf.nr_tai_range
+                        [nf_info->amf.num_of_nr_tai_range].num_of_tac_range++;
+                }
+            }
+            nf_info->amf.num_of_nr_tai_range++;
+        }
+    }
+}
+
 static void handle_validity_time(
         ogs_sbi_subscription_data_t *subscription_data,
         char *validity_time, const char *action)
@@ -719,6 +824,17 @@ void ogs_nnrf_nfm_handle_nf_status_subscribe(
 {
     OpenAPI_subscription_data_t *SubscriptionData = NULL;
 
+    int rv;
+    ogs_sbi_message_t message;
+    ogs_sbi_header_t header;
+
+    bool rc;
+    ogs_sbi_client_t *client = NULL;
+    OpenAPI_uri_scheme_e scheme = OpenAPI_uri_scheme_NULL;
+    char *fqdn = NULL;
+    uint16_t fqdn_port = 0;
+    ogs_sockaddr_t *addr = NULL, *addr6 = NULL;
+
     ogs_assert(recvmsg);
     ogs_assert(subscription_data);
 
@@ -728,45 +844,63 @@ void ogs_nnrf_nfm_handle_nf_status_subscribe(
         return;
     }
 
-    if (recvmsg->http.location) {
-        int rv;
-        ogs_sbi_message_t message;
-        ogs_sbi_header_t header;
-
-        memset(&header, 0, sizeof(header));
-        header.uri = recvmsg->http.location;
-
-        rv = ogs_sbi_parse_header(&message, &header);
-        if (rv != OGS_OK) {
-            ogs_error("Cannot parse http.location [%s]",
-                recvmsg->http.location);
-            return;
-        }
-
-        if (!message.h.resource.component[1]) {
-            ogs_error("No Subscription ID [%s]", recvmsg->http.location);
-            ogs_sbi_header_free(&header);
-            return;
-        }
-
-        ogs_sbi_subscription_data_set_id(
-                subscription_data, message.h.resource.component[1]);
-
-        ogs_sbi_header_free(&header);
-
-    } else if (SubscriptionData->subscription_id) {
-        /*
-         * For compatibility with v2.5.x and lower versions
-         *
-         * Deprecated : It will be removed soon.
-         */
-        ogs_sbi_subscription_data_set_id(
-            subscription_data, SubscriptionData->subscription_id);
-    } else {
-        ogs_error("No Subscription ID");
+    if (!recvmsg->http.location) {
+        ogs_error("No http.location");
         return;
     }
 
+    memset(&header, 0, sizeof(header));
+    header.uri = recvmsg->http.location;
+
+    rv = ogs_sbi_parse_header(&message, &header);
+    if (rv != OGS_OK) {
+        ogs_error("Cannot parse http.location [%s]",
+            recvmsg->http.location);
+        return;
+    }
+
+    if (!message.h.resource.component[1]) {
+        ogs_error("No Subscription ID [%s]", recvmsg->http.location);
+        ogs_sbi_header_free(&header);
+        return;
+    }
+
+    rc = ogs_sbi_getaddr_from_uri(
+            &scheme, &fqdn, &fqdn_port, &addr, &addr6, header.uri);
+    if (rc == false || scheme == OpenAPI_uri_scheme_NULL) {
+        ogs_error("Invalid URI [%s]", header.uri);
+        ogs_sbi_header_free(&header);
+        return;
+    }
+
+    client = ogs_sbi_client_find(scheme, fqdn, fqdn_port, addr, addr6);
+    if (!client) {
+        ogs_debug("%s: ogs_sbi_client_add()", OGS_FUNC);
+        client = ogs_sbi_client_add(scheme, fqdn, fqdn_port, addr, addr6);
+        if (!client) {
+            ogs_error("%s: ogs_sbi_client_add() failed", OGS_FUNC);
+
+            ogs_sbi_header_free(&header);
+            ogs_free(fqdn);
+            ogs_freeaddrinfo(addr);
+            ogs_freeaddrinfo(addr6);
+
+            return;
+        }
+    }
+    OGS_SBI_SETUP_CLIENT(subscription_data, client);
+
+    ogs_free(fqdn);
+    ogs_freeaddrinfo(addr);
+    ogs_freeaddrinfo(addr6);
+
+    ogs_sbi_subscription_data_set_resource_uri(
+            subscription_data, header.uri);
+    ogs_sbi_subscription_data_set_id(
+            subscription_data, message.h.resource.component[1]);
+
+    ogs_sbi_header_free(&header);
+
     /* SBI Features */
     if (SubscriptionData->nrf_supported_features) {
         subscription_data->nrf_supported_features =
@@ -822,7 +956,7 @@ bool ogs_nnrf_nfm_handle_nf_status_notify(
         ogs_error("No NotificationData");
         ogs_assert(true ==
             ogs_sbi_server_send_error(stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
-                recvmsg, "No NotificationData", NULL));
+                recvmsg, "No NotificationData", NULL, NULL));
         return false;
     }
 
@@ -830,7 +964,7 @@ bool ogs_nnrf_nfm_handle_nf_status_notify(
         ogs_error("No nfInstanceUri");
         ogs_assert(true ==
             ogs_sbi_server_send_error(stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
-                recvmsg, "No nfInstanceUri", NULL));
+                recvmsg, "No nfInstanceUri", NULL, NULL));
         return false;
     }
 
@@ -842,7 +976,7 @@ bool ogs_nnrf_nfm_handle_nf_status_notify(
         ogs_error("Cannot parse nfInstanceUri [%s]", header.uri);
         ogs_assert(true ==
             ogs_sbi_server_send_error(stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
-                recvmsg, "Cannot parse nfInstanceUri", header.uri));
+                recvmsg, "Cannot parse nfInstanceUri", header.uri, NULL));
         return false;
     }
 
@@ -850,7 +984,7 @@ bool ogs_nnrf_nfm_handle_nf_status_notify(
         ogs_error("No nfInstanceId [%s]", header.uri);
         ogs_assert(true ==
             ogs_sbi_server_send_error(stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
-                recvmsg, "Cannot parse nfInstanceUri", header.uri));
+                recvmsg, "Cannot parse nfInstanceUri", header.uri, NULL));
         ogs_sbi_header_free(&header);
         return false;
     }
@@ -861,7 +995,7 @@ bool ogs_nnrf_nfm_handle_nf_status_notify(
         ogs_assert(true ==
             ogs_sbi_server_send_error(stream, OGS_SBI_HTTP_STATUS_FORBIDDEN,
                 recvmsg, "The notification is not allowed",
-                message.h.resource.component[1]));
+                message.h.resource.component[1], NULL));
         ogs_sbi_header_free(&header);
         return false;
     }
@@ -877,7 +1011,7 @@ bool ogs_nnrf_nfm_handle_nf_status_notify(
             ogs_assert(true ==
                 ogs_sbi_server_send_error(
                     stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
-                    recvmsg, "No NFProfile", NULL));
+                    recvmsg, "No NFProfile", NULL, NULL));
             ogs_sbi_header_free(&header);
             return false;
         }
@@ -887,7 +1021,7 @@ bool ogs_nnrf_nfm_handle_nf_status_notify(
             ogs_assert(true ==
                 ogs_sbi_server_send_error(
                     stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
-                    recvmsg, "No NFProfile.NFInstanceId", NULL));
+                    recvmsg, "No NFProfile.NFInstanceId", NULL, NULL));
             ogs_sbi_header_free(&header);
             return false;
         }
@@ -897,7 +1031,7 @@ bool ogs_nnrf_nfm_handle_nf_status_notify(
             ogs_assert(true ==
                 ogs_sbi_server_send_error(
                     stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
-                    recvmsg, "No NFProfile.NFType", NULL));
+                    recvmsg, "No NFProfile.NFType", NULL, NULL));
             ogs_sbi_header_free(&header);
             return false;
         }
@@ -907,7 +1041,7 @@ bool ogs_nnrf_nfm_handle_nf_status_notify(
             ogs_assert(true ==
                 ogs_sbi_server_send_error(
                     stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
-                    recvmsg, "No NFProfile.NFStatus", NULL));
+                    recvmsg, "No NFProfile.NFStatus", NULL, NULL));
             ogs_sbi_header_free(&header);
             return false;
         }
@@ -981,7 +1115,8 @@ bool ogs_nnrf_nfm_handle_nf_status_notify(
             ogs_assert(true ==
                 ogs_sbi_server_send_error(stream,
                     OGS_SBI_HTTP_STATUS_NOT_FOUND,
-                    recvmsg, "Not found", message.h.resource.component[1]));
+                    recvmsg, "Not found", message.h.resource.component[1],
+                    NULL));
             ogs_sbi_header_free(&header);
             return false;
         }
@@ -993,7 +1128,7 @@ bool ogs_nnrf_nfm_handle_nf_status_notify(
         ogs_assert(true ==
             ogs_sbi_server_send_error(stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
                 recvmsg, "Not supported event",
-                eventstr ? eventstr : "Unknown"));
+                eventstr ? eventstr : "Unknown", NULL));
         ogs_sbi_header_free(&header);
         return false;
     }
