@@ -22,7 +22,9 @@ extern "C" {
 typedef struct OpenAPI_condition_data_s OpenAPI_condition_data_t;
 typedef struct OpenAPI_condition_data_s {
     char *cond_id;
+    bool is_activation_time_null;
     char *activation_time;
+    bool is_deactivation_time_null;
     char *deactivation_time;
     OpenAPI_access_type_e access_type;
     OpenAPI_rat_type_e rat_type;
@@ -30,7 +32,9 @@ typedef struct OpenAPI_condition_data_s {
 
 OpenAPI_condition_data_t *OpenAPI_condition_data_create(
     char *cond_id,
+    bool is_activation_time_null,
     char *activation_time,
+    bool is_deactivation_time_null,
     char *deactivation_time,
     OpenAPI_access_type_e access_type,
     OpenAPI_rat_type_e rat_type
