@@ -19,11 +19,13 @@ extern "C" {
 
 typedef struct OpenAPI_confirmation_data_s OpenAPI_confirmation_data_t;
 typedef struct OpenAPI_confirmation_data_s {
+    bool is_res_star_null;
     char *res_star;
     char *supported_features;
 } OpenAPI_confirmation_data_t;
 
 OpenAPI_confirmation_data_t *OpenAPI_confirmation_data_create(
+    bool is_res_star_null,
     char *res_star,
     char *supported_features
 );
