@@ -1,7 +1,7 @@
 /*
  * partial_success_report.h
  *
- * 
+ * Includes the information reported by the SMF when some of the PCC rules and/or session rules are not successfully installed/activated.
  */
 
 #ifndef _OpenAPI_partial_success_report_H_
@@ -13,6 +13,7 @@
 #include "../include/keyValuePair.h"
 #include "../include/binary.h"
 #include "failure_cause.h"
+#include "invalid_param.h"
 #include "policy_decision_failure_code.h"
 #include "rule_report.h"
 #include "session_rule_report.h"
@@ -29,6 +30,7 @@ typedef struct OpenAPI_partial_success_report_s {
     OpenAPI_list_t *sess_rule_reports;
     struct OpenAPI_ue_camping_rep_s *ue_camping_rep;
     OpenAPI_list_t *policy_dec_failure_reports;
+    OpenAPI_list_t *invalid_policy_decs;
 } OpenAPI_partial_success_report_t;
 
 OpenAPI_partial_success_report_t *OpenAPI_partial_success_report_create(
@@ -36,7 +38,8 @@ OpenAPI_partial_success_report_t *OpenAPI_partial_success_report_create(
     OpenAPI_list_t *rule_reports,
     OpenAPI_list_t *sess_rule_reports,
     OpenAPI_ue_camping_rep_t *ue_camping_rep,
-    OpenAPI_list_t *policy_dec_failure_reports
+    OpenAPI_list_t *policy_dec_failure_reports,
+    OpenAPI_list_t *invalid_policy_decs
 );
 void OpenAPI_partial_success_report_free(OpenAPI_partial_success_report_t *partial_success_report);
 OpenAPI_partial_success_report_t *OpenAPI_partial_success_report_parseFromJSON(cJSON *partial_success_reportJSON);
