@@ -31,6 +31,7 @@ typedef struct OpenAPI_session_management_subscription_data_s {
     OpenAPI_list_t* shared_vn_group_data_ids;
     char *shared_dnn_configurations_id;
     OpenAPI_odb_packet_services_e odb_packet_services;
+    bool is_trace_data_null;
     struct OpenAPI_trace_data_s *trace_data;
     char *shared_trace_data_id;
     OpenAPI_list_t* expected_ue_behaviours_list;
@@ -46,6 +47,7 @@ OpenAPI_session_management_subscription_data_t *OpenAPI_session_management_subsc
     OpenAPI_list_t* shared_vn_group_data_ids,
     char *shared_dnn_configurations_id,
     OpenAPI_odb_packet_services_e odb_packet_services,
+    bool is_trace_data_null,
     OpenAPI_trace_data_t *trace_data,
     char *shared_trace_data_id,
     OpenAPI_list_t* expected_ue_behaviours_list,
