@@ -27,7 +27,8 @@ int nas_5gs_send_to_gnb(amf_ue_t *amf_ue, ogs_pkbuf_t *pkbuf)
     int rv;
     ogs_assert(pkbuf);
 
-    if (!amf_ue_cycle(amf_ue)) {
+    amf_ue = amf_ue_cycle(amf_ue);
+    if (!amf_ue) {
         ogs_error("UE(amf-ue) context has already been removed");
         ogs_pkbuf_free(pkbuf);
         return OGS_NOTFOUND;
@@ -39,35 +40,22 @@ int nas_5gs_send_to_gnb(amf_ue_t *amf_ue, ogs_pkbuf_t *pkbuf)
     return rv;
 }
 
-int nas_5gs_send_to_downlink_nas_transport(amf_ue_t *amf_ue, ogs_pkbuf_t *pkbuf)
+int nas_5gs_send_to_downlink_nas_transport(
+        ran_ue_t *ran_ue, ogs_pkbuf_t *pkbuf)
 {
     int rv;
     ogs_pkbuf_t *ngapbuf = NULL;
-    ran_ue_t *ran_ue = NULL;
 
+    ogs_assert(ran_ue_cycle(ran_ue));
     ogs_assert(pkbuf);
 
-    if (!amf_ue_cycle(amf_ue)) {
-        ogs_error("UE(amf-ue) context has already been removed");
-        ogs_pkbuf_free(pkbuf);
-        return OGS_NOTFOUND;
-    }
-
-    ran_ue = ran_ue_cycle(amf_ue->ran_ue);
-    if (!ran_ue) {
-        ogs_error("NG context has already been removed");
-        ogs_pkbuf_free(pkbuf);
-        return OGS_NOTFOUND;
-    }
-
-    ngapbuf = ngap_build_downlink_nas_transport(
-            ran_ue, pkbuf, false, false);
+    ngapbuf = ngap_build_downlink_nas_transport(ran_ue, pkbuf, false, false);
     if (!ngapbuf) {
         ogs_error("ngap_build_downlink_nas_transport() failed");
         return OGS_ERROR;
     }
 
-    rv = nas_5gs_send_to_gnb(amf_ue, ngapbuf);
+    rv = ngap_send_to_ran_ue(ran_ue, ngapbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -184,15 +172,13 @@ int nas_5gs_send_registration_accept(amf_ue_t *amf_ue)
 }
 
 int nas_5gs_send_registration_reject(
-        amf_ue_t *amf_ue, ogs_nas_5gmm_cause_t gmm_cause)
+        ran_ue_t *ran_ue, amf_ue_t *amf_ue, ogs_nas_5gmm_cause_t gmm_cause)
 {
     int rv;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    if (!amf_ue_cycle(amf_ue)) {
-        ogs_error("UE(amf-ue) context has already been removed");
-        return OGS_NOTFOUND;
-    }
+    ogs_assert(ran_ue_cycle(ran_ue));
+    ogs_assert(amf_ue_cycle(amf_ue));
 
     switch (amf_ue->nas.registration.value) {
     case OGS_NAS_5GS_REGISTRATION_TYPE_INITIAL:
@@ -224,7 +210,7 @@ int nas_5gs_send_registration_reject(
         return OGS_ERROR;
     }
 
-    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+    rv = nas_5gs_send_to_downlink_nas_transport(ran_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -303,7 +289,7 @@ int nas_5gs_send_service_accept(amf_ue_t *amf_ue)
             rv = nas_5gs_send_to_gnb(amf_ue, ngapbuf);
             ogs_expect(rv == OGS_OK);
         } else {
-            rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+            rv = nas_5gs_send_to_downlink_nas_transport(amf_ue->ran_ue, gmmbuf);
             ogs_expect(rv == OGS_OK);
         }
     }
@@ -312,20 +298,13 @@ int nas_5gs_send_service_accept(amf_ue_t *amf_ue)
 }
 
 int nas_5gs_send_service_reject(
-        amf_ue_t *amf_ue, ogs_nas_5gmm_cause_t gmm_cause)
+        ran_ue_t *ran_ue, amf_ue_t *amf_ue, ogs_nas_5gmm_cause_t gmm_cause)
 {
     int rv;
     ogs_pkbuf_t *gmmbuf = NULL;
 
-    if (!amf_ue_cycle(amf_ue)) {
-        ogs_error("UE(amf-ue) context has already been removed");
-        return OGS_NOTFOUND;
-    }
-
-    if (!ran_ue_cycle(amf_ue->ran_ue)) {
-        ogs_error("NG context has already been removed");
-        return OGS_NOTFOUND;
-    }
+    ogs_assert(ran_ue_cycle(ran_ue));
+    ogs_assert(amf_ue_cycle(amf_ue));
 
     ogs_debug("[%s] Service reject", amf_ue->supi);
 
@@ -335,7 +314,7 @@ int nas_5gs_send_service_reject(
         return OGS_ERROR;
     }
 
-    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+    rv = nas_5gs_send_to_downlink_nas_transport(ran_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -370,7 +349,7 @@ int nas_5gs_send_de_registration_accept(amf_ue_t *amf_ue)
             return OGS_ERROR;
         }
 
-        rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+        rv = nas_5gs_send_to_downlink_nas_transport(amf_ue->ran_ue, gmmbuf);
         if (rv != OGS_OK) {
             ogs_error("nas_5gs_send_to_downlink_nas_transport() failed");
             return rv;
@@ -428,7 +407,7 @@ int nas_5gs_send_de_registration_request(
     ogs_timer_start(amf_ue->t3522.timer,
             amf_timer_cfg(AMF_TIMER_T3522)->duration);
 
-    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue->ran_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -470,7 +449,7 @@ int nas_5gs_send_identity_request(amf_ue_t *amf_ue)
     ogs_timer_start(amf_ue->t3570.timer,
             amf_timer_cfg(AMF_TIMER_T3570)->duration);
 
-    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue->ran_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -514,7 +493,7 @@ int nas_5gs_send_authentication_request(amf_ue_t *amf_ue)
 
     amf_metrics_inst_global_inc(AMF_METR_GLOB_CTR_AMF_AUTH_REQ);
 
-    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue->ran_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -545,7 +524,7 @@ int nas_5gs_send_authentication_reject(amf_ue_t *amf_ue)
 
     amf_metrics_inst_global_inc(AMF_METR_GLOB_CTR_AMF_AUTH_REJECT);
 
-    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue->ran_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -587,7 +566,7 @@ int nas_5gs_send_security_mode_command(amf_ue_t *amf_ue)
     ogs_timer_start(amf_ue->t3560.timer,
             amf_timer_cfg(AMF_TIMER_T3560)->duration);
 
-    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue->ran_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -648,7 +627,7 @@ int nas_5gs_send_configuration_update_command(
 
     amf_metrics_inst_global_inc(AMF_METR_GLOB_CTR_MM_CONF_UPDATE);
 
-    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue->ran_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -693,25 +672,25 @@ int nas_send_pdu_session_setup_request(amf_sess_t *sess,
     if (ran_ue->ue_context_requested == true &&
         ran_ue->initial_context_setup_request_sent == false) {
         ngapbuf = ngap_sess_build_initial_context_setup_request(
-                sess, gmmbuf, n2smbuf);
+                ran_ue, sess, gmmbuf, n2smbuf);
         if (!ngapbuf) {
             ogs_error("ngap_sess_build_initial_context_setup_request() failed");
             return OGS_ERROR;
         }
 
-        rv = nas_5gs_send_to_gnb(amf_ue, ngapbuf);
+        rv = ngap_send_to_ran_ue(ran_ue, ngapbuf);
         ogs_expect(rv == OGS_OK);
 
         ran_ue->initial_context_setup_request_sent = true;
     } else {
         ngapbuf = ngap_sess_build_pdu_session_resource_setup_request(
-                sess, gmmbuf, n2smbuf);
+                ran_ue, sess, gmmbuf, n2smbuf);
         if (!ngapbuf) {
             ogs_error("ngap_sess_build_initial_context_setup_request() failed");
             return OGS_ERROR;
         }
 
-        rv = nas_5gs_send_to_gnb(amf_ue, ngapbuf);
+        rv = ngap_send_to_ran_ue(ran_ue, ngapbuf);
         ogs_expect(rv == OGS_OK);
     }
 
@@ -739,7 +718,7 @@ int nas_send_pdu_session_modification_command(amf_sess_t *sess,
     }
     ran_ue = ran_ue_cycle(amf_ue->ran_ue);
     if (!ran_ue) {
-        ogs_warn("NG context has already been removed");
+        ogs_warn("[%s] NG context has already been removed", amf_ue->supi);
         if (n1smbuf) ogs_pkbuf_free(n1smbuf);
         ogs_pkbuf_free(n2smbuf);
         return OGS_NOTFOUND;
@@ -903,34 +882,36 @@ int nas_5gs_send_gmm_status(amf_ue_t *amf_ue, ogs_nas_5gmm_cause_t cause)
         return OGS_ERROR;
     }
 
-    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue->ran_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
 }
 
 int nas_5gs_send_gmm_reject(
-        amf_ue_t *amf_ue, ogs_nas_5gmm_cause_t gmm_cause)
+        ran_ue_t *ran_ue, amf_ue_t *amf_ue, ogs_nas_5gmm_cause_t gmm_cause)
 {
     int rv;
 
-    if (!amf_ue_cycle(amf_ue)) {
+    amf_ue = amf_ue_cycle(amf_ue);
+    if (!amf_ue) {
         ogs_error("UE(amf-ue) context has already been removed");
         return OGS_NOTFOUND;
     }
 
-    if (!ran_ue_cycle(amf_ue->ran_ue)) {
-        ogs_error("NG context has already been removed");
+    ran_ue = ran_ue_cycle(ran_ue);
+    if (!ran_ue) {
+        ogs_error("[%s] NG context has already been removed", amf_ue->supi);
         return OGS_NOTFOUND;
     }
 
     switch(amf_ue->nas.message_type) {
     case OGS_NAS_5GS_REGISTRATION_REQUEST:
-        rv = nas_5gs_send_registration_reject(amf_ue, gmm_cause);
+        rv = nas_5gs_send_registration_reject(ran_ue, amf_ue, gmm_cause);
         ogs_expect(rv == OGS_OK);
         break;
     case OGS_NAS_5GS_SERVICE_REQUEST:
-        rv = nas_5gs_send_service_reject(amf_ue, gmm_cause);
+        rv = nas_5gs_send_service_reject(ran_ue, amf_ue, gmm_cause);
         ogs_expect(rv == OGS_OK);
         break;
     default:
@@ -970,23 +951,16 @@ int nas_5gs_send_gmm_reject_from_sbi(amf_ue_t *amf_ue, int status)
 {
     int rv;
 
-    if (!amf_ue_cycle(amf_ue)) {
-        ogs_error("UE(amf-ue) context has already been removed");
-        return OGS_NOTFOUND;
-    }
+    ogs_assert(amf_ue);
 
-    if (!ran_ue_cycle(amf_ue->ran_ue)) {
-        ogs_error("NG context has already been removed");
-        return OGS_NOTFOUND;
-    }
-
-    rv = nas_5gs_send_gmm_reject(amf_ue, gmm_cause_from_sbi(status));
+    rv = nas_5gs_send_gmm_reject(
+            amf_ue->ran_ue, amf_ue, gmm_cause_from_sbi(status));
     ogs_expect(rv == OGS_OK);
 
     return rv;
 }
 
-int nas_5gs_send_dl_nas_transport(amf_sess_t *sess,
+int nas_5gs_send_dl_nas_transport(ran_ue_t *ran_ue, amf_sess_t *sess,
         uint8_t payload_container_type, ogs_pkbuf_t *payload_container,
         ogs_nas_5gmm_cause_t cause, uint8_t backoff_time)
 {
@@ -996,15 +970,21 @@ int nas_5gs_send_dl_nas_transport(amf_sess_t *sess,
     amf_ue_t *amf_ue = NULL;
 
     ogs_assert(sess);
+    sess = amf_sess_cycle(sess);
+    if (!sess) {
+        ogs_error("Session has already been removed");
+        return OGS_NOTFOUND;
+    }
 
-    amf_ue = sess->amf_ue;
-    if (!amf_ue_cycle(amf_ue)) {
+    amf_ue = amf_ue_cycle(sess->amf_ue);
+    if (!amf_ue) {
         ogs_error("UE(amf-ue) context has already been removed");
         return OGS_NOTFOUND;
     }
 
-    if (!ran_ue_cycle(amf_ue->ran_ue)) {
-        ogs_error("NG context has already been removed");
+    ran_ue = ran_ue_cycle(ran_ue);
+    if (!ran_ue) {
+        ogs_error("[%s] NG context has already been removed", amf_ue->supi);
         return OGS_NOTFOUND;
     }
 
@@ -1019,7 +999,7 @@ int nas_5gs_send_dl_nas_transport(amf_sess_t *sess,
         ogs_error("gmm_build_dl_nas_transport() failed");
         return OGS_ERROR;
     }
-    rv = nas_5gs_send_to_downlink_nas_transport(amf_ue, gmmbuf);
+    rv = nas_5gs_send_to_downlink_nas_transport(ran_ue, gmmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -1038,22 +1018,28 @@ int nas_5gs_send_dl_nas_transport(amf_sess_t *sess,
  * As such, this function 'nas_5gs_send_gsm_reject()' must be used
  * only when an N1 SM message has been forwarded to the SMF.
  */
-int nas_5gs_send_gsm_reject(amf_sess_t *sess,
+int nas_5gs_send_gsm_reject(ran_ue_t *ran_ue, amf_sess_t *sess,
         uint8_t payload_container_type, ogs_pkbuf_t *payload_container)
 {
     int rv;
     amf_ue_t *amf_ue = NULL;
 
     ogs_assert(sess);
+    sess = amf_sess_cycle(sess);
+    if (!sess) {
+        ogs_error("Session has already been removed");
+        return OGS_NOTFOUND;
+    }
 
-    amf_ue = sess->amf_ue;
-    if (!amf_ue_cycle(amf_ue)) {
+    amf_ue = amf_ue_cycle(sess->amf_ue);
+    if (!amf_ue) {
         ogs_error("UE(amf-ue) context has already been removed");
         return OGS_NOTFOUND;
     }
 
-    if (!ran_ue_cycle(amf_ue->ran_ue)) {
-        ogs_error("NG context has already been removed");
+    ran_ue = ran_ue_cycle(ran_ue);
+    if (!ran_ue) {
+        ogs_error("[%s] NG context has already been removed", amf_ue->supi);
         return OGS_NOTFOUND;
     }
 
@@ -1061,29 +1047,36 @@ int nas_5gs_send_gsm_reject(amf_sess_t *sess,
     ogs_assert(payload_container);
 
     rv = nas_5gs_send_dl_nas_transport(
-            sess, payload_container_type, payload_container, 0, 0);
+            ran_ue, sess, payload_container_type, payload_container, 0, 0);
     ogs_expect(rv == OGS_OK);
 
     return rv;
 }
 
 int nas_5gs_send_back_gsm_message(
-        amf_sess_t *sess, ogs_nas_5gmm_cause_t cause, uint8_t backoff_time)
+        ran_ue_t *ran_ue, amf_sess_t *sess,
+        ogs_nas_5gmm_cause_t cause, uint8_t backoff_time)
 {
     int rv;
     ogs_pkbuf_t *pbuf = NULL;
     amf_ue_t *amf_ue = NULL;
 
     ogs_assert(sess);
+    sess = amf_sess_cycle(sess);
+    if (!sess) {
+        ogs_error("Session has already been removed");
+        return OGS_NOTFOUND;
+    }
 
-    amf_ue = sess->amf_ue;
-    if (!amf_ue_cycle(amf_ue)) {
+    amf_ue = amf_ue_cycle(sess->amf_ue);
+    if (!amf_ue) {
         ogs_error("UE(amf-ue) context has already been removed");
         return OGS_NOTFOUND;
     }
 
-    if (!ran_ue_cycle(amf_ue->ran_ue)) {
-        ogs_error("NG context has already been removed");
+    ran_ue = ran_ue_cycle(ran_ue);
+    if (!ran_ue) {
+        ogs_error("[%s] NG context has already been removed", amf_ue->supi);
         return OGS_NOTFOUND;
     }
 
@@ -1097,7 +1090,8 @@ int nas_5gs_send_back_gsm_message(
     }
 
     rv = nas_5gs_send_dl_nas_transport(
-            sess, sess->payload_container_type, pbuf, cause, backoff_time);
+            ran_ue, sess, sess->payload_container_type, pbuf,
+            cause, backoff_time);
     ogs_expect(rv == OGS_OK);
 
     return rv;
