@@ -79,19 +79,16 @@ void amf_nnrf_handle_nf_discover(
             sess = (amf_sess_t *)sbi_object;
             ogs_assert(sess);
                         
-            amf_ue = sess->amf_ue;
-            ogs_assert(amf_ue);
-                        
             ogs_error("[%d:%d] (NF discover) No [%s]", sess->psi, sess->pti,
                         ogs_sbi_service_type_to_name(service_type));
             if (sess->payload_container_type) {
-                r = nas_5gs_send_back_gsm_message(sess,
+                r = nas_5gs_send_back_gsm_message(sess->ran_ue, sess,
                         OGS_5GMM_CAUSE_PAYLOAD_WAS_NOT_FORWARDED,
                         AMF_NAS_BACKOFF_TIME);
                 ogs_expect(r == OGS_OK);
                 ogs_assert(r != OGS_ERROR);
             } else {
-                r = ngap_send_error_indication2(amf_ue,
+                r = ngap_send_error_indication2(sess->ran_ue,
                         NGAP_Cause_PR_transport,
                         NGAP_CauseTransport_transport_resource_unavailable);
                 ogs_expect(r == OGS_OK);
