@@ -272,17 +272,15 @@ ogs_sbi_request_t *amf_nsmf_pdusession_build_update_sm_context(
 
     ogs_assert(param);
     ogs_assert(sess);
-    ogs_assert(sess->sm_context_ref);
+    ogs_assert(sess->sm_context.resource_uri);
     amf_ue = sess->amf_ue;
     ogs_assert(amf_ue);
 
     memset(&message, 0, sizeof(message));
     message.h.method = (char *)OGS_SBI_HTTP_METHOD_POST;
-    message.h.service.name = (char *)OGS_SBI_SERVICE_NAME_NSMF_PDUSESSION;
-    message.h.api.version = (char *)OGS_SBI_API_V1;
-    message.h.resource.component[0] = (char *)OGS_SBI_RESOURCE_NAME_SM_CONTEXTS;
-    message.h.resource.component[1] = sess->sm_context_ref;
-    message.h.resource.component[2] = (char *)OGS_SBI_RESOURCE_NAME_MODIFY;
+    message.h.uri = ogs_msprintf("%s/%s",
+            sess->sm_context.resource_uri, OGS_SBI_RESOURCE_NAME_MODIFY);
+    ogs_assert(message.h.uri);
 
     memset(&ueLocation, 0, sizeof(ueLocation));
     memset(&SmContextUpdateData, 0, sizeof(SmContextUpdateData));
@@ -377,6 +375,8 @@ ogs_sbi_request_t *amf_nsmf_pdusession_build_update_sm_context(
     ogs_expect(request);
 
 end:
+    if (message.h.uri)
+        ogs_free(message.h.uri);
     if (ueLocation.nr_location) {
         if (ueLocation.nr_location->ue_location_timestamp)
             ogs_free(ueLocation.nr_location->ue_location_timestamp);
@@ -405,18 +405,15 @@ ogs_sbi_request_t *amf_nsmf_pdusession_build_release_sm_context(
     OpenAPI_user_location_t ueLocation;
 
     ogs_assert(sess);
-    ogs_assert(sess->sm_context_ref);
+    ogs_assert(sess->sm_context.resource_uri);
     amf_ue = sess->amf_ue;
     ogs_assert(amf_ue);
 
     memset(&message, 0, sizeof(message));
     message.h.method = (char *)OGS_SBI_HTTP_METHOD_POST;
-    message.h.service.name = (char *)OGS_SBI_SERVICE_NAME_NSMF_PDUSESSION;
-    message.h.api.version = (char *)OGS_SBI_API_V1;
-    message.h.resource.component[0] =
-        (char *)OGS_SBI_RESOURCE_NAME_SM_CONTEXTS;
-    message.h.resource.component[1] = sess->sm_context_ref;
-    message.h.resource.component[2] = (char *)OGS_SBI_RESOURCE_NAME_RELEASE;
+    message.h.uri = ogs_msprintf("%s/%s",
+            sess->sm_context.resource_uri, OGS_SBI_RESOURCE_NAME_RELEASE);
+    ogs_assert(message.h.uri);
 
     memset(&SmContextReleaseData, 0, sizeof(SmContextReleaseData));
 
@@ -460,6 +457,8 @@ ogs_sbi_request_t *amf_nsmf_pdusession_build_release_sm_context(
     ogs_expect(request);
 
 end:
+    if (message.h.uri)
+        ogs_free(message.h.uri);
     if (ueLocation.nr_location) {
         if (ueLocation.nr_location->ue_location_timestamp)
             ogs_free(ueLocation.nr_location->ue_location_timestamp);
