@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019 by Sukchan Lee <acetcom@gmail.com>
+ * Copyright (C) 2019-2023 by Sukchan Lee <acetcom@gmail.com>
  *
  * This file is part of Open5GS.
  *
@@ -184,7 +184,7 @@ int hss_context_parse_config(void)
                 const char *hss_key = ogs_yaml_iter_key(&hss_iter);
                 ogs_assert(hss_key);
                 if (!strcmp(hss_key, "freeDiameter")) {
-                    yaml_node_t *node = 
+                    yaml_node_t *node =
                         yaml_document_get_node(document, hss_iter.pair->value);
                     ogs_assert(node);
                     if (node->type == YAML_SCALAR_NODE) {
@@ -197,10 +197,10 @@ int hss_context_parse_config(void)
                             const char *fd_key = ogs_yaml_iter_key(&fd_iter);
                             ogs_assert(fd_key);
                             if (!strcmp(fd_key, "identity")) {
-                                self.diam_config->cnf_diamid = 
+                                self.diam_config->cnf_diamid =
                                     ogs_yaml_iter_value(&fd_iter);
                             } else if (!strcmp(fd_key, "realm")) {
-                                self.diam_config->cnf_diamrlm = 
+                                self.diam_config->cnf_diamrlm =
                                     ogs_yaml_iter_value(&fd_iter);
                             } else if (!strcmp(fd_key, "port")) {
                                 const char *v = ogs_yaml_iter_value(&fd_iter);
@@ -209,7 +209,7 @@ int hss_context_parse_config(void)
                                 const char *v = ogs_yaml_iter_value(&fd_iter);
                                 if (v) self.diam_config->cnf_port_tls = atoi(v);
                             } else if (!strcmp(fd_key, "listen_on")) {
-                                self.diam_config->cnf_addr = 
+                                self.diam_config->cnf_addr =
                                     ogs_yaml_iter_value(&fd_iter);
                             } else if (!strcmp(fd_key, "no_fwd")) {
                                 self.diam_config->cnf_flags.no_fwd =
@@ -296,7 +296,8 @@ int hss_context_parse_config(void)
                                         if (!strcmp(conn_key, "identity")) {
                                             identity = ogs_yaml_iter_value(
                                                     &conn_iter);
-                                        } else if (!strcmp(conn_key, "addr")) {
+                                        } else if (!strcmp(conn_key,
+                                                    "address")) {
                                             addr = ogs_yaml_iter_value(
                                                     &conn_iter);
                                         } else if (!strcmp(conn_key, "port")) {
@@ -327,8 +328,17 @@ int hss_context_parse_config(void)
                         }
                     }
                 } else if (!strcmp(hss_key, "sms_over_ims")) {
-                            self.sms_over_ims = 
+                            self.sms_over_ims =
                                 ogs_yaml_iter_value(&hss_iter);
+                } else if (!strcmp(hss_key, "use_mongodb_change_stream")) {
+#if MONGOC_CHECK_VERSION(1, 9, 0)
+                    self.use_mongodb_change_stream =
+                        ogs_yaml_iter_bool(&hss_iter);
+#else
+                    self.use_mongodb_change_stream = false;
+#endif
+                } else if (!strcmp(hss_key, "metrics")) {
+                    /* handle config in metrics library */
                 } else
                     ogs_warn("unknown key `%s`", hss_key);
             }
@@ -511,6 +521,7 @@ static hss_imsi_t *imsi_add(char *id)
     ogs_hash_set(self.imsi_hash, imsi->id, strlen(imsi->id), imsi);
 
     ogs_list_add(&self.imsi_list, imsi);
+    hss_metrics_inst_global_inc(HSS_METR_GLOB_GAUGE_IMSI);
 
     return imsi;
 }
@@ -520,6 +531,7 @@ static void imsi_remove(hss_imsi_t *imsi)
     ogs_assert(imsi);
 
     ogs_list_remove(&self.imsi_list, imsi);
+    hss_metrics_inst_global_dec(HSS_METR_GLOB_GAUGE_IMSI);
 
     ogs_assert(imsi->id);
     ogs_hash_set(self.imsi_hash, imsi->id, strlen(imsi->id), NULL);
@@ -561,6 +573,7 @@ static hss_impi_t *impi_add(char *id)
     ogs_hash_set(self.impi_hash, impi->id, strlen(impi->id), impi);
 
     ogs_list_add(&self.impi_list, impi);
+    hss_metrics_inst_global_inc(HSS_METR_GLOB_GAUGE_IMPI);
 
     return impi;
 }
@@ -570,6 +583,7 @@ static void impi_remove(hss_impi_t *impi)
     ogs_assert(impi);
 
     ogs_list_remove(&self.impi_list, impi);
+    hss_metrics_inst_global_dec(HSS_METR_GLOB_GAUGE_IMPI);
 
     impu_remove_all(impi);
 
@@ -625,7 +639,9 @@ static hss_impu_t *impu_add(hss_impi_t *impi, char *id)
     ogs_hash_set(self.impu_hash, impu->id, strlen(impu->id), impu);
 
     impu->impi = impi;
+
     ogs_list_add(&impi->impu_list, impu);
+    hss_metrics_inst_global_inc(HSS_METR_GLOB_GAUGE_IMPU);
 
     return impu;
 }
@@ -639,6 +655,7 @@ static void impu_remove(hss_impu_t *impu)
     ogs_assert(impi);
 
     ogs_list_remove(&impi->impu_list, impu);
+    hss_metrics_inst_global_dec(HSS_METR_GLOB_GAUGE_IMPU);
 
     ogs_assert(impu->id);
     ogs_hash_set(self.impu_hash, impu->id, strlen(impu->id), NULL);
@@ -979,185 +996,185 @@ char *hss_cx_download_user_data(
         }
 
         if(self.sms_over_ims) {
-            user_data = ogs_mstrcatf(user_data, "%s", 
-                        ogs_diam_cx_xml_ifc_s); 
+            user_data = ogs_mstrcatf(user_data, "%s",
+                        ogs_diam_cx_xml_ifc_s);
             ogs_assert(user_data);
 
-              user_data = ogs_mstrcatf(user_data, "%s%s%s", 
+              user_data = ogs_mstrcatf(user_data, "%s%s%s",
                           ogs_diam_cx_xml_priority_s,
-                          "2", 
-                          ogs_diam_cx_xml_priority_e); 
+                          "2",
+                          ogs_diam_cx_xml_priority_e);
               ogs_assert(user_data);
 
-              user_data = ogs_mstrcatf(user_data, "%s", 
-                          ogs_diam_cx_xml_tp_s); 
+              user_data = ogs_mstrcatf(user_data, "%s",
+                          ogs_diam_cx_xml_tp_s);
               ogs_assert(user_data);
 
-                user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                            ogs_diam_cx_xml_cnf_s, 
-                            "1", 
-                            ogs_diam_cx_xml_cnf_e); 
+                user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                            ogs_diam_cx_xml_cnf_s,
+                            "1",
+                            ogs_diam_cx_xml_cnf_e);
                 ogs_assert(user_data);
 
-                user_data = ogs_mstrcatf(user_data, "%s", 
-                            ogs_diam_cx_xml_spt_s); 
+                user_data = ogs_mstrcatf(user_data, "%s",
+                            ogs_diam_cx_xml_spt_s);
                 ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                              ogs_diam_cx_xml_condition_negated_s, 
-                              "0", 
-                              ogs_diam_cx_xml_condition_negated_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                              ogs_diam_cx_xml_condition_negated_s,
+                              "0",
+                              ogs_diam_cx_xml_condition_negated_e);
                   ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                              ogs_diam_cx_xml_group_s, 
-                              "1", 
-                              ogs_diam_cx_xml_group_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                              ogs_diam_cx_xml_group_s,
+                              "1",
+                              ogs_diam_cx_xml_group_e);
                   ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                              ogs_diam_cx_xml_method_s, 
-                              "MESSAGE", 
-                              ogs_diam_cx_xml_method_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                              ogs_diam_cx_xml_method_s,
+                              "MESSAGE",
+                              ogs_diam_cx_xml_method_e);
                   ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s", 
-                              ogs_diam_cx_xml_extension_s); 
+                  user_data = ogs_mstrcatf(user_data, "%s",
+                              ogs_diam_cx_xml_extension_s);
                   ogs_assert(user_data);
 
-                    user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                                ogs_diam_cx_xml_registration_type_s, 
-                                "0", 
-                                ogs_diam_cx_xml_registration_type_e); 
+                    user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                                ogs_diam_cx_xml_registration_type_s,
+                                "0",
+                                ogs_diam_cx_xml_registration_type_e);
                     ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s", 
-                              ogs_diam_cx_xml_extension_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s",
+                              ogs_diam_cx_xml_extension_e);
                   ogs_assert(user_data);
 
-                user_data = ogs_mstrcatf(user_data, "%s", 
-                            ogs_diam_cx_xml_spt_e); 
+                user_data = ogs_mstrcatf(user_data, "%s",
+                            ogs_diam_cx_xml_spt_e);
                 ogs_assert(user_data);
 
-                user_data = ogs_mstrcatf(user_data, "%s", 
-                            ogs_diam_cx_xml_spt_s); 
+                user_data = ogs_mstrcatf(user_data, "%s",
+                            ogs_diam_cx_xml_spt_s);
                 ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                              ogs_diam_cx_xml_condition_negated_s, 
-                              "0", 
-                              ogs_diam_cx_xml_condition_negated_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                              ogs_diam_cx_xml_condition_negated_s,
+                              "0",
+                              ogs_diam_cx_xml_condition_negated_e);
                   ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                              ogs_diam_cx_xml_group_s, 
-                              "2", 
-                              ogs_diam_cx_xml_group_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                              ogs_diam_cx_xml_group_s,
+                              "2",
+                              ogs_diam_cx_xml_group_e);
                   ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s", 
-                              ogs_diam_cx_xml_sip_hdr_s); 
+                  user_data = ogs_mstrcatf(user_data, "%s",
+                              ogs_diam_cx_xml_sip_hdr_s);
                   ogs_assert(user_data);
 
-                    user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                                ogs_diam_cx_xml_header_s, 
-                                "Content-Type", 
-                                ogs_diam_cx_xml_header_e); 
+                    user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                                ogs_diam_cx_xml_header_s,
+                                "Content-Type",
+                                ogs_diam_cx_xml_header_e);
                     ogs_assert(user_data);
 
-                    user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                                ogs_diam_cx_xml_content_s, 
-                                "application/vnd.3gpp.sms", 
-                                ogs_diam_cx_xml_content_e); 
+                    user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                                ogs_diam_cx_xml_content_s,
+                                "application/vnd.3gpp.sms",
+                                ogs_diam_cx_xml_content_e);
                     ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s", 
-                              ogs_diam_cx_xml_sip_hdr_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s",
+                              ogs_diam_cx_xml_sip_hdr_e);
                   ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s", 
-                              ogs_diam_cx_xml_extension_s); 
+                  user_data = ogs_mstrcatf(user_data, "%s",
+                              ogs_diam_cx_xml_extension_s);
                   ogs_assert(user_data);
 
-                    user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                                ogs_diam_cx_xml_registration_type_s, 
-                                "0", 
-                                ogs_diam_cx_xml_registration_type_e); 
+                    user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                                ogs_diam_cx_xml_registration_type_s,
+                                "0",
+                                ogs_diam_cx_xml_registration_type_e);
                     ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s", 
-                              ogs_diam_cx_xml_extension_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s",
+                              ogs_diam_cx_xml_extension_e);
                   ogs_assert(user_data);
 
-                user_data = ogs_mstrcatf(user_data, "%s", 
-                            ogs_diam_cx_xml_spt_e); 
+                user_data = ogs_mstrcatf(user_data, "%s",
+                            ogs_diam_cx_xml_spt_e);
                 ogs_assert(user_data);
 
-                user_data = ogs_mstrcatf(user_data, "%s", 
-                            ogs_diam_cx_xml_spt_s); 
+                user_data = ogs_mstrcatf(user_data, "%s",
+                            ogs_diam_cx_xml_spt_s);
                 ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                              ogs_diam_cx_xml_condition_negated_s, 
-                              "0", 
-                              ogs_diam_cx_xml_condition_negated_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                              ogs_diam_cx_xml_condition_negated_s,
+                              "0",
+                              ogs_diam_cx_xml_condition_negated_e);
                   ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                              ogs_diam_cx_xml_group_s, 
-                              "3", 
-                              ogs_diam_cx_xml_group_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                              ogs_diam_cx_xml_group_s,
+                              "3",
+                              ogs_diam_cx_xml_group_e);
                   ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                              ogs_diam_cx_xml_session_case_s, 
-                              "0", 
-                              ogs_diam_cx_xml_session_case_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                              ogs_diam_cx_xml_session_case_s,
+                              "0",
+                              ogs_diam_cx_xml_session_case_e);
                   ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s", 
-                              ogs_diam_cx_xml_extension_s); 
+                  user_data = ogs_mstrcatf(user_data, "%s",
+                              ogs_diam_cx_xml_extension_s);
                   ogs_assert(user_data);
 
-                    user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                                ogs_diam_cx_xml_registration_type_s, 
-                                "0", 
-                                ogs_diam_cx_xml_registration_type_e); 
+                    user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                                ogs_diam_cx_xml_registration_type_s,
+                                "0",
+                                ogs_diam_cx_xml_registration_type_e);
                     ogs_assert(user_data);
 
-                  user_data = ogs_mstrcatf(user_data, "%s", 
-                              ogs_diam_cx_xml_extension_e); 
+                  user_data = ogs_mstrcatf(user_data, "%s",
+                              ogs_diam_cx_xml_extension_e);
                   ogs_assert(user_data);
 
-                user_data = ogs_mstrcatf(user_data, "%s", 
-                            ogs_diam_cx_xml_spt_e); 
+                user_data = ogs_mstrcatf(user_data, "%s",
+                            ogs_diam_cx_xml_spt_e);
                 ogs_assert(user_data);
 
-              user_data = ogs_mstrcatf(user_data, "%s", 
-                          ogs_diam_cx_xml_tp_e); 
+              user_data = ogs_mstrcatf(user_data, "%s",
+                          ogs_diam_cx_xml_tp_e);
               ogs_assert(user_data);
 
-              user_data = ogs_mstrcatf(user_data, "%s", 
-                          ogs_diam_cx_xml_app_server_s); 
+              user_data = ogs_mstrcatf(user_data, "%s",
+                          ogs_diam_cx_xml_app_server_s);
               ogs_assert(user_data);
 
-                user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                            ogs_diam_cx_xml_server_name_s, 
-                            self.sms_over_ims, 
-                            ogs_diam_cx_xml_server_name_e); 
+                user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                            ogs_diam_cx_xml_server_name_s,
+                            self.sms_over_ims,
+                            ogs_diam_cx_xml_server_name_e);
                 ogs_assert(user_data);
 
-                user_data = ogs_mstrcatf(user_data, "%s%s%s", 
-                            ogs_diam_cx_xml_default_handling_s, 
+                user_data = ogs_mstrcatf(user_data, "%s%s%s",
+                            ogs_diam_cx_xml_default_handling_s,
                             "0",
-                            ogs_diam_cx_xml_default_handling_e); 
+                            ogs_diam_cx_xml_default_handling_e);
                 ogs_assert(user_data);
 
-              user_data = ogs_mstrcatf(user_data, "%s", 
-                          ogs_diam_cx_xml_app_server_e); 
+              user_data = ogs_mstrcatf(user_data, "%s",
+                          ogs_diam_cx_xml_app_server_e);
               ogs_assert(user_data);
 
-            user_data = ogs_mstrcatf(user_data, "%s", 
+            user_data = ogs_mstrcatf(user_data, "%s",
                         ogs_diam_cx_xml_ifc_e);
             ogs_assert(user_data);
         }
@@ -1175,19 +1192,74 @@ char *hss_cx_download_user_data(
     return user_data;
 }
 
+static int poll_change_stream(void);
+static int process_change_stream(const bson_t *document);
+
 int hss_db_poll_change_stream(void)
 {
     int rv;
 
     ogs_thread_mutex_lock(&self.db_lock);
 
-    rv = ogs_dbi_poll_change_stream();
+    rv = poll_change_stream();
 
     ogs_thread_mutex_unlock(&self.db_lock);
 
     return rv;
 }
 
+static int poll_change_stream(void)
+{
+#if MONGOC_CHECK_VERSION(1, 9, 0)
+    int rv;
+
+    const bson_t *document;
+    const bson_t *err_document;
+    bson_error_t error;
+
+    while (mongoc_change_stream_next(ogs_mongoc()->stream, &document)) {
+        rv = process_change_stream(document);
+        if (rv != OGS_OK) return rv;
+    }
+
+    if (mongoc_change_stream_error_document(ogs_mongoc()->stream, &error,
+            &err_document)) {
+        if (!bson_empty (err_document)) {
+            ogs_debug("Server Error: %s\n",
+            bson_as_relaxed_extended_json(err_document, NULL));
+        } else {
+            ogs_debug("Client Error: %s\n", error.message);
+        }
+        return OGS_ERROR;
+    }
+
+    return OGS_OK;
+# else
+    return OGS_ERROR;
+#endif
+}
+
+static int process_change_stream(const bson_t *document)
+{
+    int rv;
+
+    hss_event_t *e = NULL;
+
+    e = hss_event_new(HSS_EVENT_DBI_MESSAGE);
+    ogs_assert(e);
+    e->dbi.document = bson_copy(document);
+    rv = ogs_queue_push(ogs_app()->queue, e);
+    if (rv != OGS_OK) {
+        ogs_error("ogs_queue_push() failed:%d", (int)rv);
+        bson_destroy(e->dbi.document);
+        hss_event_free(e);
+    } else {
+        ogs_pollset_notify(ogs_app()->pollset);
+    }
+
+    return OGS_OK;
+}
+
 int hss_handle_change_event(const bson_t *document)
 {
     bson_iter_t iter, child1_iter, child2_iter;
@@ -1215,7 +1287,7 @@ int hss_handle_change_event(const bson_t *document)
         bson_iter_recurse(&iter, &child1_iter);
         while (bson_iter_next(&child1_iter)) {
             const char *key = bson_iter_key(&child1_iter);
-            if (!strcmp(key, "imsi") && 
+            if (!strcmp(key, "imsi") &&
                     BSON_ITER_HOLDS_UTF8(&child1_iter)) {
                 utf8 = (char *)bson_iter_utf8(&child1_iter, &length);
                 imsi_bcd = ogs_strndup(utf8,
@@ -1234,44 +1306,50 @@ int hss_handle_change_event(const bson_t *document)
         bson_iter_recurse(&iter, &child1_iter);
         while (bson_iter_next(&child1_iter)) {
             const char *key = bson_iter_key(&child1_iter);
-            if (!strcmp(key, "updatedFields") && 
+            if (!strcmp(key, "updatedFields") &&
                     BSON_ITER_HOLDS_DOCUMENT(&child1_iter)) {
                 bson_iter_recurse(&child1_iter, &child2_iter);
                 while (bson_iter_next(&child2_iter)) {
                     const char *child2_key = bson_iter_key(&child2_iter);
-                    if (!strcmp(child2_key, 
-                            "request_cancel_location") && 
+                    if (!strcmp(child2_key,
+                            "request_cancel_location") &&
                             BSON_ITER_HOLDS_BOOL(&child2_iter)) {
                         send_clr_flag = (char *)bson_iter_bool(&child2_iter);
-                    } else if (!strncmp(child2_key, 
-                            "access_restriction_data",
-                            strlen("access_restriction_data"))) {
+                    } else if (!strncmp(child2_key,
+                                OGS_ACCESS_RESTRICTION_DATA_STRING,
+                                strlen(OGS_ACCESS_RESTRICTION_DATA_STRING))) {
                         send_idr_flag = true;
                         subdatamask = (subdatamask | OGS_DIAM_S6A_SUBDATA_ARD);
-                    } else if (!strncmp(child2_key, 
-                            "subscriber_status", 
-                            strlen("subscriber_status"))) {
+                    } else if (!strncmp(child2_key,
+                                OGS_SUBSCRIBER_STATUS_STRING,
+                                strlen(OGS_SUBSCRIBER_STATUS_STRING))) {
                         send_idr_flag = true;
-                        subdatamask = (subdatamask | 
+                        subdatamask = (subdatamask |
                             OGS_DIAM_S6A_SUBDATA_SUB_STATUS);
-                    } else if (!strncmp(child2_key, 
-                            "network_access_mode",
-                            strlen("network_access_mode"))) {
+                    } else if (!strncmp(child2_key,
+                                OGS_OPERATOR_DETERMINED_BARRING_STRING,
+                            strlen(OGS_OPERATOR_DETERMINED_BARRING_STRING))) {
+                        send_idr_flag = true;
+                        subdatamask = (subdatamask |
+                            OGS_DIAM_S6A_SUBDATA_OP_DET_BARRING);
+                    } else if (!strncmp(child2_key,
+                                OGS_NETWORK_ACCESS_MODE_STRING,
+                                strlen(OGS_NETWORK_ACCESS_MODE_STRING))) {
                         send_idr_flag = true;
                         subdatamask = (subdatamask | OGS_DIAM_S6A_SUBDATA_NAM);
                     } else if (!strncmp(child2_key, "ambr", strlen("ambr"))) {
                         send_idr_flag = true;
-                        subdatamask = (subdatamask | 
+                        subdatamask = (subdatamask |
                             OGS_DIAM_S6A_SUBDATA_UEAMBR);
-                    } else if (!strncmp(child2_key, 
-                            "subscribed_rau_tau_timer",
-                            strlen("subscribed_rau_tau_timer"))) {
+                    } else if (!strncmp(child2_key,
+                                OGS_SUBSCRIBED_RAU_TAU_TIMER_STRING,
+                                strlen(OGS_SUBSCRIBED_RAU_TAU_TIMER_STRING))) {
                         send_idr_flag = true;
-                        subdatamask = (subdatamask | 
+                        subdatamask = (subdatamask |
                             OGS_DIAM_S6A_SUBDATA_RAU_TAU_TIMER);
                     } else if (!strncmp(child2_key, "slice", strlen("slice"))) {
                         send_idr_flag = true;
-                        subdatamask = (subdatamask | 
+                        subdatamask = (subdatamask |
                             OGS_DIAM_S6A_SUBDATA_APN_CONFIG);
                     }
                 }
