@@ -20,6 +20,7 @@
 #include "hss-context.h"
 #include "hss-fd-path.h"
 #include "hss-sm.h"
+#include "metrics.h"
 
 
 static ogs_thread_t *thread;
@@ -35,7 +36,13 @@ int hss_initialize(void)
     rv = ogs_app_parse_local_conf(APP_NAME);
     if (rv != OGS_OK) return rv;
 
+    hss_metrics_init();
+
     hss_context_init();
+    hss_event_init();
+
+    rv = ogs_metrics_context_parse_config(APP_NAME);
+    if (rv != OGS_OK) return rv;
 
     rv = hss_context_parse_config();
     if (rv != OGS_OK) return rv;
@@ -44,6 +51,8 @@ int hss_initialize(void)
             ogs_app()->logger.domain, ogs_app()->logger.level);
     if (rv != OGS_OK) return rv;
 
+    ogs_metrics_context_open(ogs_metrics_self());
+
     rv = ogs_dbi_init(ogs_app()->db_uri);
     if (rv != OGS_OK) return rv;
 
@@ -64,11 +73,14 @@ void hss_terminate(void)
 
     hss_event_term();
     ogs_thread_destroy(thread);
+    ogs_metrics_context_close(ogs_metrics_self());
 
     hss_fd_final();
 
     ogs_dbi_final();
     hss_context_final();
+    hss_event_final();
+    hss_metrics_final();
 
     return;
 }
