@@ -62,6 +62,18 @@ static void build_qos_profile_from_session(ogs_gtp1_qos_profile_decoded_t *qos_p
 
     qos_pdec->qos_profile.arp = session->qos.arp.priority_level;
 
+    /* 3GPP TS 23.107 "Delivery order should be set to 'no' for PDP Type =
+     * 'IPv4' or 'IPv6'. The SGSN shall ensure that the appropriate value is set."
+     * 3GPP TS 23.401 D.3.5 2b NOTE4: The GTP and PDCP sequence numbers are not
+     * relevant as the network does not configure usage of "delivery order
+     * required" [...] as described in clause "compatibility issues" (4.8.1) */
+    qos_pdec->qos_profile.data.delivery_order = OGS_GTP1_DELIVERY_ORDER_NO;
+
+    qos_pdec->qos_profile.data.delivery_erroneous_sdu = OGS_GTP1_DELIVERY_ERR_SDU_NO;
+
+    /* Maximum SDU Size: Encode it as 1500, the maximum for IP 3GPP TS 23.107 Table 4, Note 4) */
+    qos_pdec->qos_profile.data.max_sdu_size = 0x96;
+
      /* 3GPP TS 23.401 Annex E table Table E.3 */
     /* Also take into account table 7 in 3GPP TS 23.107 9.1.2.2 */
     switch (session->qos.index) { /* QCI */
@@ -135,7 +147,7 @@ static int sess_fill_pdp_context_decoded(mme_sess_t *sess, ogs_gtp1_pdp_context_
         .asi = OGS_GTP1_PDPCTX_ACTIVITY_STATUS_IND_NO,
         .order = OGS_GTP1_PDPCTX_REORDERING_REQUIRED_NO,
         /* 3GPP TS 23.401 Annex D3.5.5 2b.:
-         * "The GTP equence numbers received from the old 3G-SGSN are only relevant if
+         * "The GTP sequence numbers received from the old 3G-SGSN are only relevant if
          * delivery order is required for the PDP context (QoS profile)."
          * NOTE 4: "The GTP and PDCP sequence numbers are not relevant" */
         .snd = 0,
@@ -153,7 +165,7 @@ static int sess_fill_pdp_context_decoded(mme_sess_t *sess, ogs_gtp1_pdp_context_
     ogs_cpystrn(pdpctx_dec->apn, sess->session->name, sizeof(pdpctx_dec->apn));
 
     ogs_list_for_each(&sess->bearer_list, bearer) {
-        pdpctx_dec->nsapi  = bearer->ebi;
+        pdpctx_dec->nsapi = bearer->ebi; /* 3GPP TS 23.401 5.2.1, TS 23.060 14.4 */
         pdpctx_dec->sapi = 3; /* FIXME. Using 3 = default for now. Maybe use 0 = UNASSIGNED ?*/
         build_qos_profile_from_session(&pdpctx_dec->qos_sub, sess, bearer);
         //FIXME: sort out where to get each one:
