@@ -50,14 +50,17 @@ int nas_eps_send_emm_to_esm(mme_ue_t *mme_ue,
     int rv;
     ogs_pkbuf_t *esmbuf = NULL;
 
+    ogs_assert(esm_message_container);
+    if (!esm_message_container->length) {
+        ogs_error("Invalid ESM Message Container");
+        return OGS_ERROR;
+    }
+
     if (!mme_ue_cycle(mme_ue)) {
         ogs_error("UE(mme-ue) context has already been removed");
         return OGS_NOTFOUND;
     }
 
-    ogs_assert(esm_message_container);
-    ogs_assert(esm_message_container->length);
-
     /* The Packet Buffer(pkbuf_t) for NAS message MUST make a HEADROOM. 
      * When calculating AES_CMAC, we need to use the headroom of the packet. */
     esmbuf = ogs_pkbuf_alloc(NULL,
@@ -73,32 +76,27 @@ int nas_eps_send_emm_to_esm(mme_ue_t *mme_ue,
     return rv;
 }
 
-int nas_eps_send_to_downlink_nas_transport(mme_ue_t *mme_ue, ogs_pkbuf_t *pkbuf)
+int nas_eps_send_to_downlink_nas_transport(
+        enb_ue_t *enb_ue, ogs_pkbuf_t *pkbuf)
 {
     int rv;
     ogs_pkbuf_t *s1apbuf = NULL;
 
     ogs_assert(pkbuf);
 
-    if (!mme_ue_cycle(mme_ue)) {
-        ogs_error("UE(mme-ue) context has already been removed");
-        ogs_pkbuf_free(pkbuf);
-        return OGS_NOTFOUND;
-    }
-
-    if (!enb_ue_cycle(mme_ue->enb_ue)) {
+    if (!enb_ue_cycle(enb_ue)) {
         ogs_error("S1 context has already been removed");
         ogs_pkbuf_free(pkbuf);
         return OGS_NOTFOUND;
     }
 
-    s1apbuf = s1ap_build_downlink_nas_transport(mme_ue->enb_ue, pkbuf);
+    s1apbuf = s1ap_build_downlink_nas_transport(enb_ue, pkbuf);
     if (!s1apbuf) {
         ogs_error("s1ap_build_downlink_nas_transport() failed");
         return OGS_ERROR;
     }
 
-    rv = nas_eps_send_to_enb(mme_ue, s1apbuf);
+    rv = s1ap_send_to_enb_ue(enb_ue, s1apbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -108,7 +106,6 @@ int nas_eps_send_attach_accept(mme_ue_t *mme_ue)
 {
     int rv;
     mme_sess_t *sess = NULL;
-    mme_bearer_t *bearer = NULL;
     ogs_pkbuf_t *s1apbuf = NULL;
     ogs_pkbuf_t *esmbuf = NULL, *emmbuf = NULL;
 
@@ -124,10 +121,10 @@ int nas_eps_send_attach_accept(mme_ue_t *mme_ue)
 
     sess = mme_sess_first(mme_ue);
     ogs_assert(sess);
-    ogs_assert(mme_sess_next(sess) == NULL);
-    bearer = mme_default_bearer_in_sess(sess);
-    ogs_assert(bearer);
-    ogs_assert(mme_bearer_next(bearer) == NULL);
+    if (mme_sess_next(sess)) {
+        ogs_error("There should only be one SESSION");
+        return OGS_ERROR;
+    }
 
     ogs_debug("[%s] Attach accept", mme_ue->imsi_bcd);
 
@@ -180,7 +177,7 @@ int nas_eps_send_attach_accept(mme_ue_t *mme_ue)
     return rv;
 }
 
-int nas_eps_send_attach_reject(mme_ue_t *mme_ue,
+int nas_eps_send_attach_reject(enb_ue_t *enb_ue, mme_ue_t *mme_ue,
     ogs_nas_emm_cause_t emm_cause, ogs_nas_esm_cause_t esm_cause)
 {
     int rv;
@@ -192,7 +189,7 @@ int nas_eps_send_attach_reject(mme_ue_t *mme_ue,
         return OGS_NOTFOUND;
     }
 
-    if (!enb_ue_cycle(mme_ue->enb_ue)) {
+    if (!enb_ue_cycle(enb_ue)) {
         ogs_error("S1 context has already been removed");
         return OGS_NOTFOUND;
     }
@@ -215,7 +212,7 @@ int nas_eps_send_attach_reject(mme_ue_t *mme_ue,
         ogs_error("emm_build_attach_reject() failed");
         return OGS_ERROR;
     }
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(enb_ue, emmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -257,7 +254,7 @@ int nas_eps_send_identity_request(mme_ue_t *mme_ue)
     ogs_timer_start(mme_ue->t3470.timer, 
             mme_timer_cfg(MME_TIMER_T3470)->duration);
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, emmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -299,7 +296,7 @@ int nas_eps_send_authentication_request(mme_ue_t *mme_ue)
     ogs_timer_start(mme_ue->t3460.timer, 
             mme_timer_cfg(MME_TIMER_T3460)->duration);
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, emmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -341,7 +338,7 @@ int nas_eps_send_security_mode_command(mme_ue_t *mme_ue)
     ogs_timer_start(mme_ue->t3460.timer, 
             mme_timer_cfg(MME_TIMER_T3460)->duration);
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, emmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -370,7 +367,7 @@ int nas_eps_send_authentication_reject(mme_ue_t *mme_ue)
         return OGS_ERROR;
     }
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, emmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -412,7 +409,7 @@ int nas_eps_send_detach_request(mme_ue_t *mme_ue)
     ogs_timer_start(mme_ue->t3422.timer, 
             mme_timer_cfg(MME_TIMER_T3422)->duration);    
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, emmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -444,7 +441,7 @@ int nas_eps_send_detach_accept(mme_ue_t *mme_ue)
             return OGS_ERROR;
         }
 
-        rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+        rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, emmbuf);
         if (rv != OGS_OK) {
             ogs_error("nas_eps_send_to_downlink_nas_transport() failed");
             return rv;
@@ -482,7 +479,7 @@ int nas_eps_send_pdn_connectivity_reject(
     if (create_action == OGS_GTP_CREATE_IN_ATTACH_REQUEST) {
         /* During the UE-attach process, we'll send Attach-Reject
          * with pyggybacking PDN-connectivity-Reject */
-        rv = nas_eps_send_attach_reject(mme_ue,
+        rv = nas_eps_send_attach_reject(mme_ue->enb_ue, mme_ue,
             OGS_NAS_EMM_CAUSE_ESM_FAILURE, esm_cause);
         if (rv != OGS_OK) {
             ogs_error("nas_eps_send_attach_reject() failed");
@@ -501,7 +498,7 @@ int nas_eps_send_pdn_connectivity_reject(
             return OGS_ERROR;
         }
 
-        rv = nas_eps_send_to_downlink_nas_transport(mme_ue, esmbuf);
+        rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, esmbuf);
         ogs_expect(rv == OGS_OK);
     }
 
@@ -546,7 +543,7 @@ int nas_eps_send_esm_information_request(mme_bearer_t *bearer)
     ogs_timer_start(bearer->t3489.timer, 
             mme_timer_cfg(MME_TIMER_T3489)->duration);
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, esmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, esmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -688,7 +685,7 @@ int nas_eps_send_modify_bearer_context_request(
         rv = nas_eps_send_to_enb(mme_ue, s1apbuf);
         ogs_expect(rv == OGS_OK);
     } else {
-        rv = nas_eps_send_to_downlink_nas_transport(mme_ue, esmbuf);
+        rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, esmbuf);
         ogs_expect(rv == OGS_OK);
     }
 
@@ -760,7 +757,7 @@ int nas_eps_send_bearer_resource_allocation_reject(
         return OGS_ERROR;
     }
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, esmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, esmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -791,7 +788,7 @@ int nas_eps_send_bearer_resource_modification_reject(
         return OGS_ERROR;
     }
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, esmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, esmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -844,7 +841,7 @@ int nas_eps_send_tau_accept(
         rv = nas_eps_send_to_enb(mme_ue, s1apbuf);
         ogs_expect(rv == OGS_OK);
     } else if (procedureCode == S1AP_ProcedureCode_id_downlinkNASTransport) {
-        rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+        rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, emmbuf);
         ogs_expect(rv == OGS_OK);
     } else
         ogs_assert_if_reached();
@@ -852,7 +849,8 @@ int nas_eps_send_tau_accept(
     return rv;
 }
 
-int nas_eps_send_tau_reject(mme_ue_t *mme_ue, ogs_nas_emm_cause_t emm_cause)
+int nas_eps_send_tau_reject(
+        enb_ue_t *enb_ue, mme_ue_t *mme_ue, ogs_nas_emm_cause_t emm_cause)
 {
     int rv;
     ogs_pkbuf_t *emmbuf = NULL;
@@ -862,7 +860,7 @@ int nas_eps_send_tau_reject(mme_ue_t *mme_ue, ogs_nas_emm_cause_t emm_cause)
         return OGS_NOTFOUND;
     }
 
-    if (!enb_ue_cycle(mme_ue->enb_ue)) {
+    if (!enb_ue_cycle(enb_ue)) {
         ogs_error("S1 context has already been removed");
         return OGS_NOTFOUND;
     }
@@ -876,14 +874,14 @@ int nas_eps_send_tau_reject(mme_ue_t *mme_ue, ogs_nas_emm_cause_t emm_cause)
         return OGS_ERROR;
     }
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(enb_ue, emmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
 }
 
-int nas_eps_send_service_reject(mme_ue_t *mme_ue,
-        ogs_nas_emm_cause_t emm_cause)
+int nas_eps_send_service_reject(
+        enb_ue_t *enb_ue, mme_ue_t *mme_ue, ogs_nas_emm_cause_t emm_cause)
 {
     int rv;
     ogs_pkbuf_t *emmbuf = NULL;
@@ -893,7 +891,7 @@ int nas_eps_send_service_reject(mme_ue_t *mme_ue,
         return OGS_NOTFOUND;
     }
 
-    if (!enb_ue_cycle(mme_ue->enb_ue)) {
+    if (!enb_ue_cycle(enb_ue)) {
         ogs_error("S1 context has already been removed");
         return OGS_NOTFOUND;
     }
@@ -907,7 +905,7 @@ int nas_eps_send_service_reject(mme_ue_t *mme_ue,
         return OGS_ERROR;
     }
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(enb_ue, emmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -936,7 +934,7 @@ int nas_eps_send_cs_service_notification(mme_ue_t *mme_ue)
         return OGS_ERROR;
     }
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, emmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
@@ -969,7 +967,7 @@ int nas_eps_send_downlink_nas_transport(
         return OGS_ERROR;
     }
 
-    rv = nas_eps_send_to_downlink_nas_transport(mme_ue, emmbuf);
+    rv = nas_eps_send_to_downlink_nas_transport(mme_ue->enb_ue, emmbuf);
     ogs_expect(rv == OGS_OK);
 
     return rv;
