@@ -23,6 +23,8 @@
 #include "mme-context.h"
 #include "mme-event.h"
 
+#include "sgsap-build.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -45,6 +47,7 @@ int sgsap_send_location_update_request(mme_ue_t *mme_ue);
 int sgsap_send_tmsi_reallocation_complete(mme_ue_t *mme_ue);
 int sgsap_send_detach_indication(mme_ue_t *mme_ue);
 int sgsap_send_mo_csfb_indication(mme_ue_t *mme_ue);
+int sgsap_send_paging_reject(mme_ue_t *mme_ue, uint8_t sgs_cause);
 int sgsap_send_service_request(mme_ue_t *mme_ue, uint8_t emm_mode);
 int sgsap_send_reset_ack(mme_vlr_t *vlr);
 int sgsap_send_uplink_unitdata(mme_ue_t *mme_ue,
