@@ -96,8 +96,8 @@ void pcf_sm_state_operational(ogs_fsm_t *s, pcf_event_t *e)
                             pcf_ue->supi, sess->psi, message->h.uri);
                     ogs_assert(true ==
                         ogs_sbi_server_send_error(stream,
-                            OGS_SBI_HTTP_STATUS_FORBIDDEN, message,
-                            "Invalid HTTP method", message->h.uri));
+                            OGS_SBI_HTTP_STATUS_METHOD_NOT_ALLOWED, message,
+                            "Invalid HTTP method", message->h.uri, NULL));
                 END
             }
             break;
@@ -116,8 +116,8 @@ void pcf_sm_state_operational(ogs_fsm_t *s, pcf_event_t *e)
                                 message->h.resource.component[2]);
                         ogs_assert(true ==
                             ogs_sbi_server_send_error(stream,
-                                OGS_SBI_HTTP_STATUS_FORBIDDEN, message,
-                                "Invalid resource name", message->h.uri));
+                                OGS_SBI_HTTP_STATUS_BAD_REQUEST, message,
+                                "Invalid resource name", message->h.uri, NULL));
                     END
                 } else {
                     SWITCH(message->h.method)
@@ -130,8 +130,8 @@ void pcf_sm_state_operational(ogs_fsm_t *s, pcf_event_t *e)
                                 pcf_ue->supi, sess->psi, message->h.method);
                         ogs_assert(true ==
                             ogs_sbi_server_send_error(stream,
-                                OGS_SBI_HTTP_STATUS_FORBIDDEN, message,
-                                "Invalid HTTP method", message->h.uri));
+                                OGS_SBI_HTTP_STATUS_METHOD_NOT_ALLOWED, message,
+                                "Invalid HTTP method", message->h.uri, NULL));
                     END
                 }
             } else {
@@ -145,8 +145,8 @@ void pcf_sm_state_operational(ogs_fsm_t *s, pcf_event_t *e)
                             pcf_ue->supi, sess->psi, message->h.method);
                     ogs_assert(true ==
                         ogs_sbi_server_send_error(stream,
-                            OGS_SBI_HTTP_STATUS_FORBIDDEN, message,
-                            "Invalid HTTP method", message->h.uri));
+                            OGS_SBI_HTTP_STATUS_METHOD_NOT_ALLOWED, message,
+                            "Invalid HTTP method", message->h.uri, NULL));
                 END
             }
             break;
@@ -176,14 +176,42 @@ void pcf_sm_state_operational(ogs_fsm_t *s, pcf_event_t *e)
                                 OGS_SBI_HTTP_STATUS_NOT_FOUND) {
                             ogs_warn("[%s:%d] Cannot find SUPI [%d]",
                                 pcf_ue->supi, sess->psi, message->res_status);
+                            /*
+                             * TS29.512
+                             * 4.2.2.2 SM Policy Association establishment
+                             *
+                             * If the user information received within the "supi"
+                             * attribute is unknown, the PCF shall reject the
+                             * request with an HTTP "400 Bad Request" response
+                             * message including the "cause" attribute of the
+                             * ProblemDetails data structure set to "USER_UNKNOWN".
+                             */
+                            ogs_assert(true ==
+                                ogs_sbi_server_send_error(
+                                    stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
+                                    NULL, "End user is unknown to the PCF",
+                                    pcf_ue->supi, "USER_UNKNOWN"));
                         } else {
                             ogs_error("[%s:%d] HTTP response error [%d]",
                                 pcf_ue->supi, sess->psi, message->res_status);
+                            /*
+                             * TS29.512
+                             * 4.2.2.2 SM Policy Association establishment
+                             *
+                             * If the PCF, based on local configuration and/or
+                             * operator policies, denies the creation of the
+                             * Individual SM Policy resource, the PCF may reject
+                             * the request and include in an HTTP "403 Forbidden"
+                             * response message the "cause" attribute of the
+                             * ProblemDetails data structure set to
+                             * "POLICY_CONTEXT_DENIED".
+                             */
+                            ogs_assert(true ==
+                                ogs_sbi_server_send_error(
+                                    stream, OGS_SBI_HTTP_STATUS_FORBIDDEN,
+                                    NULL, "HTTP response error",
+                                    pcf_ue->supi, "POLICY_CONTEXT_DENIED"));
                         }
-                        ogs_assert(true ==
-                            ogs_sbi_server_send_error(
-                                stream, message->res_status,
-                                NULL, "HTTP response error", pcf_ue->supi));
                         break;
                     }
 
