@@ -218,7 +218,8 @@ void smf_gsm_state_initial(ogs_fsm_t *s, smf_event_t *e)
         switch(gtp2_message->h.type) {
         case OGS_GTP2_CREATE_SESSION_REQUEST_TYPE:
             gtp2_cause = smf_s5c_handle_create_session_request(sess,
-                            e->gtp_xact, gtp2_message);
+                            e->gtp_xact,
+                            &e->gtp2_message->create_session_request);
             if (gtp2_cause != OGS_GTP2_CAUSE_REQUEST_ACCEPTED) {
                 send_gtp_create_err_msg(sess, e->gtp_xact, gtp2_cause);
                 return;
@@ -620,7 +621,8 @@ void smf_gsm_state_wait_pfcp_establishment(ogs_fsm_t *s, smf_event_t *e)
                 ogs_assert(gtp_xact);
 
                 pfcp_cause = smf_epc_n4_handle_session_establishment_response(
-                        sess, pfcp_xact, pfcp_message);
+                        sess, pfcp_xact,
+                        &pfcp_message->pfcp_session_establishment_response);
                 if (pfcp_cause != OGS_PFCP_CAUSE_REQUEST_ACCEPTED) {
                     /* FIXME: tear down Gy and Gx */
                     gtp_cause = gtp_cause_from_pfcp(
@@ -669,7 +671,8 @@ void smf_gsm_state_wait_pfcp_establishment(ogs_fsm_t *s, smf_event_t *e)
                 smf_bearer_binding(sess);
             } else {
                 pfcp_cause = smf_5gc_n4_handle_session_establishment_response(
-                        sess, pfcp_xact, pfcp_message);
+                        sess, pfcp_xact,
+                        &pfcp_message->pfcp_session_establishment_response);
                 if (pfcp_cause != OGS_PFCP_CAUSE_REQUEST_ACCEPTED) {
                     OGS_FSM_TRAN(s, smf_gsm_state_5gc_n1_n2_reject);
                     return;
@@ -724,6 +727,7 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
 
     ogs_pfcp_xact_t *pfcp_xact = NULL;
     ogs_pfcp_message_t *pfcp_message = NULL;
+    uint8_t pfcp_cause;
 
     ogs_diam_gy_message_t *gy_message = NULL;
     uint32_t diam_err;
@@ -781,7 +785,8 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
         switch(gtp2_message->h.type) {
         case OGS_GTP2_DELETE_SESSION_REQUEST_TYPE:
             gtp2_cause = smf_s5c_handle_delete_session_request(
-                            sess, e->gtp_xact, gtp2_message);
+                            sess, e->gtp_xact,
+                            &gtp2_message->delete_session_request);
             if (gtp2_cause != OGS_GTP2_CAUSE_REQUEST_ACCEPTED) {
                 ogs_gtp2_send_error_message(e->gtp_xact, sess->sgw_s5c_teid,
                         OGS_GTP2_DELETE_SESSION_RESPONSE_TYPE, gtp2_cause);
@@ -791,7 +796,7 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
             break;
         case OGS_GTP2_DELETE_BEARER_RESPONSE_TYPE:
             release = smf_s5c_handle_delete_bearer_response(
-                sess, e->gtp_xact, gtp2_message);
+                sess, e->gtp_xact, &e->gtp2_message->delete_bearer_response);
             if (release) {
                 e->gtp_xact = NULL;
                 OGS_FSM_TRAN(s, smf_gsm_state_wait_pfcp_deletion);
@@ -834,6 +839,14 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
             OGS_FSM_TRAN(s, smf_gsm_state_epc_session_will_release);
             break;
 
+        case OGS_PFCP_SESSION_REPORT_REQUEST_TYPE:
+            pfcp_cause = smf_n4_handle_session_report_request(sess, pfcp_xact,
+                            &pfcp_message->pfcp_session_report_request);
+            if (pfcp_cause != OGS_PFCP_CAUSE_REQUEST_ACCEPTED) {
+               OGS_FSM_TRAN(s, smf_gsm_state_wait_pfcp_deletion);
+            }
+            break;
+
         default:
             ogs_error("cannot handle PFCP message type[%d]",
                     pfcp_message->h.type);
@@ -931,9 +944,7 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
                 } else {
                     SWITCH(sbi_message->h.resource.component[2])
                     CASE(OGS_SBI_RESOURCE_NAME_DELETE)
-                        if (sess->policy_association_id)
-                            ogs_free(sess->policy_association_id);
-                        sess->policy_association_id = NULL;
+                        PCF_SM_POLICY_CLEAR(sess);
 
                         if (sbi_message->res_status !=
                                 OGS_SBI_HTTP_STATUS_NO_CONTENT) {
@@ -1072,7 +1083,7 @@ void smf_gsm_state_operational(ogs_fsm_t *s, smf_event_t *e)
             break;
 
         case OGS_NAS_5GS_PDU_SESSION_RELEASE_REQUEST:
-            if (sess->policy_association_id) {
+            if (PCF_SM_POLICY_ASSOCIATED(sess)) {
                 smf_npcf_smpolicycontrol_param_t param;
 
                 memset(&param, 0, sizeof(param));
@@ -1306,7 +1317,8 @@ void smf_gsm_state_wait_pfcp_deletion(ogs_fsm_t *s, smf_event_t *e)
                 gtp_xact = pfcp_xact->assoc_xact;
 
                 pfcp_cause = smf_epc_n4_handle_session_deletion_response(
-                            sess, pfcp_xact, pfcp_message);
+                            sess, pfcp_xact,
+                            &pfcp_message->pfcp_session_deletion_response);
                 if (pfcp_cause != OGS_PFCP_CAUSE_REQUEST_ACCEPTED) {
                     /* FIXME: tear down Gy and Gx */
                     ogs_assert(gtp_xact);
@@ -1329,7 +1341,8 @@ void smf_gsm_state_wait_pfcp_deletion(ogs_fsm_t *s, smf_event_t *e)
                 ogs_pfcp_xact_commit(pfcp_xact);
 
                 status = smf_5gc_n4_handle_session_deletion_response(
-                            sess, stream, trigger, pfcp_message);
+                            sess, stream, trigger,
+                            &pfcp_message->pfcp_session_deletion_response);
                 if (status != OGS_SBI_HTTP_STATUS_OK) {
                     ogs_error(
                         "[%d] smf_5gc_n4_handle_session_deletion_response() "
@@ -1807,7 +1820,7 @@ void smf_gsm_state_5gc_n1_n2_reject(ogs_fsm_t *s, smf_event_t *e)
 
     switch (e->h.id) {
     case OGS_FSM_ENTRY_SIG:
-        if (sess->policy_association_id) {
+        if (PCF_SM_POLICY_ASSOCIATED(sess)) {
             smf_npcf_smpolicycontrol_param_t param;
             int r = 0;
 
@@ -1849,9 +1862,7 @@ void smf_gsm_state_5gc_n1_n2_reject(ogs_fsm_t *s, smf_event_t *e)
                 } else {
                     SWITCH(sbi_message->h.resource.component[2])
                     CASE(OGS_SBI_RESOURCE_NAME_DELETE)
-                        if (sess->policy_association_id)
-                            ogs_free(sess->policy_association_id);
-                        sess->policy_association_id = NULL;
+                        PCF_SM_POLICY_CLEAR(sess);
 
                         if (sbi_message->res_status !=
                                 OGS_SBI_HTTP_STATUS_NO_CONTENT) {
