@@ -1,4 +1,4 @@
-/*
+/* Gy Interface, 3GPP TS 32.299
  * Copyright (C) 2019 by Sukchan Lee <acetcom@gmail.com>
  * Copyright (C) 2022 by sysmocom - s.f.m.c. GmbH <info@sysmocom.de>
  *
@@ -47,12 +47,14 @@ static void urr_update_volume(smf_sess_t *sess, ogs_pfcp_urr_t *urr, ogs_diam_gy
         urr->vol_quota.total_volume = 0;
     }
 
-    /* Volume Threshold */
-    if (gy_message->cca.volume_threshold) {
+    /* Volume Threshold, requires Volume Quota for calculations */
+    if (gy_message->cca.volume_threshold &&
+        gy_message->cca.granted.cc_total_octets >= gy_message->cca.volume_threshold) {
         ogs_debug("Adding Volume Threshold total_octets=%" PRIu32, gy_message->cca.volume_threshold);
         urr->rep_triggers.volume_threshold = 1;
         urr->vol_threshold.tovol = 1;
-        urr->vol_threshold.total_volume = gy_message->cca.volume_threshold;
+        urr->vol_threshold.total_volume = (gy_message->cca.granted.cc_total_octets -
+                                           gy_message->cca.volume_threshold);
     } else {
         urr->rep_triggers.volume_threshold = 0;
         urr->vol_threshold.tovol = 0;
@@ -94,6 +96,7 @@ static void urr_update_time(smf_sess_t *sess, ogs_pfcp_urr_t *urr, ogs_diam_gy_m
         urr->meas_method &= ~OGS_PFCP_MEASUREMENT_METHOD_DURATION;
     }
 
+    /* Time Quota */
     if (time_quota) {
         ogs_debug("Adding Time Quota secs=%" PRIu32, time_quota);
         urr->rep_triggers.time_quota = 1;
@@ -103,34 +106,53 @@ static void urr_update_time(smf_sess_t *sess, ogs_pfcp_urr_t *urr, ogs_diam_gy_m
         urr->time_quota = 0;
     }
 
-    if (gy_message->cca.time_threshold) {
+    /* Time Threshold, requires Time Quota for calculations */
+    if (gy_message->cca.time_threshold &&
+        time_quota >= gy_message->cca.time_threshold) {
         ogs_debug("Adding Time Threshold secs=%" PRIu32, gy_message->cca.time_threshold);
         urr->rep_triggers.time_threshold = 1;
-        urr->time_threshold = gy_message->cca.time_threshold;
+        urr->time_threshold = (time_quota - gy_message->cca.time_threshold);
     } else {
         urr->rep_triggers.time_threshold = 0;
         urr->time_threshold = 0;
     }
 }
 
-/* Returns ER_DIAMETER_SUCCESS on success, Diameter error code on failue. */
+/* Returns ER_DIAMETER_SUCCESS on success, Diameter error code on failue.
+ * Upon failure, CCR-Terminate is needed based on "need_termination" value (this
+ * may happen eg. if messaged RC is successful but MSCC RC is rejected). */
 uint32_t smf_gy_handle_cca_initial_request(
         smf_sess_t *sess, ogs_diam_gy_message_t *gy_message,
-        ogs_gtp_xact_t *gtp_xact)
+        ogs_gtp_xact_t *gtp_xact,
+        bool *need_termination)
 {
     smf_bearer_t *bearer;
 
     ogs_assert(sess);
     ogs_assert(gy_message);
     ogs_assert(gtp_xact);
+    ogs_assert(need_termination);
 
     ogs_debug("[Gy CCA Initial]");
     ogs_debug("    SGW_S5C_TEID[0x%x] PGW_S5C_TEID[0x%x]",
             sess->sgw_s5c_teid, sess->smf_n4_teid);
 
-    if (gy_message->result_code != ER_DIAMETER_SUCCESS)
+    *need_termination = false;
+    if (gy_message->result_code != ER_DIAMETER_SUCCESS) {
+        ogs_warn("Gy CCA Initial Diameter failure: res=%u",
+            gy_message->result_code);
         return gy_message->err ? *gy_message->err :
                                  ER_DIAMETER_AUTHENTICATION_REJECTED;
+    }
+    if (gy_message->cca.result_code != ER_DIAMETER_SUCCESS) {
+        ogs_warn("Gy CCA Initial Diameter Multiple-Services-Credit-Control Result-Code=%u",
+            gy_message->cca.result_code);
+        /* Message RC was successful but MSCC was rejected. The session needs to
+         * be tear down through CCR-T: */
+        *need_termination = true;
+        return gy_message->cca.err ? *gy_message->cca.err :
+                                     ER_DIAMETER_AUTHENTICATION_REJECTED;
+    }
 
     bearer = smf_default_bearer_in_sess(sess);
     ogs_assert(bearer);
@@ -142,6 +164,7 @@ uint32_t smf_gy_handle_cca_initial_request(
     /* Configure based on what we received from OCS: */
     urr_update_time(sess, bearer->urr, gy_message);
     urr_update_volume(sess, bearer->urr, gy_message);
+    sess->gy.final_unit = gy_message->cca.final.cc_final_action_present;
 
     /* Associate acconting URR each direction PDR: */
     ogs_pfcp_pdr_associate_urr(bearer->ul_pdr, bearer->urr);
@@ -149,7 +172,7 @@ uint32_t smf_gy_handle_cca_initial_request(
     return ER_DIAMETER_SUCCESS;
 }
 
-void smf_gy_handle_cca_update_request(
+uint32_t smf_gy_handle_cca_update_request(
         smf_sess_t *sess, ogs_diam_gy_message_t *gy_message,
         ogs_pfcp_xact_t *pfcp_xact)
 {
@@ -173,12 +196,16 @@ void smf_gy_handle_cca_update_request(
             sess->sgw_s5c_teid, sess->smf_n4_teid);
 
     if (gy_message->result_code != ER_DIAMETER_SUCCESS) {
-        ogs_warn("Gy CCA Update Diameter failure: res=%u err=%u",
-            gy_message->result_code, *gy_message->err);
-        // TODO: generate new gtp_xact from sess here? */
-        //ogs_assert(OGS_OK ==
-        //    smf_epc_pfcp_send_session_deletion_request(sess, gtp_xact));
-        return;
+        ogs_warn("Gy CCA Update Diameter failure: Result-Code=%u",
+            gy_message->result_code);
+        return gy_message->err ? *gy_message->err :
+                                 ER_DIAMETER_AUTHENTICATION_REJECTED;
+    }
+    if (gy_message->cca.result_code != ER_DIAMETER_SUCCESS) {
+        ogs_warn("Gy CCA Update Diameter Multiple-Services-Credit-Control Result-Code=%u",
+            gy_message->cca.result_code);
+        return gy_message->cca.err ? *gy_message->cca.err :
+                                     ER_DIAMETER_AUTHENTICATION_REJECTED;
     }
 
     bearer = smf_default_bearer_in_sess(sess);
@@ -195,6 +222,7 @@ void smf_gy_handle_cca_update_request(
 
     urr_update_time(sess, urr, gy_message);
     urr_update_volume(sess, urr, gy_message);
+    sess->gy.final_unit = gy_message->cca.final.cc_final_action_present;
     /* Associate accounting URR each direction PDR: */
     ogs_pfcp_pdr_associate_urr(bearer->ul_pdr, urr);
     ogs_pfcp_pdr_associate_urr(bearer->dl_pdr, urr);
@@ -234,6 +262,7 @@ void smf_gy_handle_cca_update_request(
                 OGS_GTP1_CAUSE_REACTIACTION_REQUESTED);
         ogs_assert(rv == OGS_OK);
     }
+    return ER_DIAMETER_SUCCESS;
 }
 
 uint32_t smf_gy_handle_cca_termination_request(
@@ -242,7 +271,6 @@ uint32_t smf_gy_handle_cca_termination_request(
 {
     ogs_assert(sess);
     ogs_assert(gy_message);
-    ogs_assert(gtp_xact);
 
     ogs_debug("[SMF] Delete Session Response");
     ogs_debug("    SGW_S5C_TEID[0x%x] SMF_N4_TEID[0x%x]",
