@@ -144,7 +144,7 @@ static int sbi_status_from_pfcp(uint8_t pfcp_cause)
  * other cause value on failure */
 uint8_t smf_5gc_n4_handle_session_establishment_response(
         smf_sess_t *sess, ogs_pfcp_xact_t *xact,
-        ogs_pfcp_message_t *pfcp_message)
+        ogs_pfcp_session_establishment_response_t *rsp)
 {
     int i;
 
@@ -156,12 +156,8 @@ uint8_t smf_5gc_n4_handle_session_establishment_response(
     ogs_pfcp_pdr_t *pdr = NULL;
     ogs_pfcp_far_t *far = NULL;
 
-    ogs_pfcp_session_establishment_response_t *rsp = NULL;
-
     ogs_assert(sess);
     ogs_assert(xact);
-    ogs_assert(pfcp_message);
-    rsp = &pfcp_message->pfcp_session_establishment_response;
     ogs_assert(rsp);
 
     ogs_debug("Session Establishment Response [5gc]");
@@ -244,22 +240,18 @@ uint8_t smf_5gc_n4_handle_session_establishment_response(
 
 void smf_5gc_n4_handle_session_modification_response(
         smf_sess_t *sess, ogs_pfcp_xact_t *xact,
-        ogs_pfcp_message_t *pfcp_message)
+        ogs_pfcp_session_modification_response_t *rsp)
 {
     int status = 0;
     uint64_t flags = 0;
     ogs_sbi_stream_t *stream = NULL;
     smf_bearer_t *qos_flow = NULL;
 
-    ogs_pfcp_session_modification_response_t *rsp = NULL;
-
     OGS_LIST(pdr_to_create_list);
 
     ogs_debug("Session Modification Response [5gc]");
 
     ogs_assert(xact);
-    ogs_assert(pfcp_message);
-    rsp = &pfcp_message->pfcp_session_modification_response;
     ogs_assert(rsp);
 
     flags = xact->modify_flags;
@@ -673,16 +665,12 @@ void smf_5gc_n4_handle_session_modification_response(
 
 int smf_5gc_n4_handle_session_deletion_response(
         smf_sess_t *sess, ogs_sbi_stream_t *stream, int trigger,
-        ogs_pfcp_message_t *pfcp_message)
+        ogs_pfcp_session_deletion_response_t *rsp)
 {
     int status = 0;
 
-    ogs_pfcp_session_deletion_response_t *rsp = NULL;
-
     ogs_debug("Session Deletion Response [5gc]");
 
-    ogs_assert(pfcp_message);
-    rsp = &pfcp_message->pfcp_session_deletion_response;
     ogs_assert(rsp);
     ogs_assert(trigger);
 
@@ -737,7 +725,7 @@ int smf_5gc_n4_handle_session_deletion_response(
  * other cause value on failure */
 uint8_t smf_epc_n4_handle_session_establishment_response(
         smf_sess_t *sess, ogs_pfcp_xact_t *xact,
-        ogs_pfcp_message_t *pfcp_message)
+        ogs_pfcp_session_establishment_response_t *rsp)
 {
     uint8_t cause_value = OGS_PFCP_CAUSE_REQUEST_ACCEPTED;
 
@@ -745,12 +733,8 @@ uint8_t smf_epc_n4_handle_session_establishment_response(
 
     ogs_pfcp_f_seid_t *up_f_seid = NULL;
 
-    ogs_pfcp_session_establishment_response_t *rsp = NULL;
-
     ogs_assert(sess);
     ogs_assert(xact);
-    ogs_assert(pfcp_message);
-    rsp = &pfcp_message->pfcp_session_establishment_response;
     ogs_assert(rsp);
 
     ogs_debug("Session Establishment Response [epc]");
@@ -844,7 +828,7 @@ uint8_t smf_epc_n4_handle_session_establishment_response(
 void smf_epc_n4_handle_session_modification_response(
         smf_sess_t *sess, ogs_pfcp_xact_t *xact,
         ogs_gtp2_message_t *recv_message,
-        ogs_pfcp_message_t *pfcp_message)
+        ogs_pfcp_session_modification_response_t *rsp)
 {
     int i;
 
@@ -860,13 +844,9 @@ void smf_epc_n4_handle_session_modification_response(
     ogs_pfcp_pdr_t *pdr = NULL;
     ogs_pfcp_far_t *far = NULL;
 
-    ogs_pfcp_session_modification_response_t *rsp = NULL;
-
     OGS_LIST(pdr_to_create_list);
 
     ogs_assert(xact);
-    ogs_assert(pfcp_message);
-    rsp = &pfcp_message->pfcp_session_modification_response;
     ogs_assert(rsp);
 
     ogs_debug("Session Modification Response [epc]");
@@ -1113,17 +1093,13 @@ void smf_epc_n4_handle_session_modification_response(
 
 uint8_t smf_epc_n4_handle_session_deletion_response(
         smf_sess_t *sess, ogs_pfcp_xact_t *xact,
-        ogs_pfcp_message_t *pfcp_message)
+        ogs_pfcp_session_deletion_response_t *rsp)
 {
     smf_bearer_t *bearer = NULL;
     unsigned int i;
 
-    ogs_pfcp_session_deletion_response_t *rsp = NULL;
-
     ogs_assert(sess);
     ogs_assert(xact);
-    ogs_assert(pfcp_message);
-    rsp = &pfcp_message->pfcp_session_deletion_response;
     ogs_assert(rsp);
 
     ogs_debug("Session Deletion Response [epc]");
@@ -1171,9 +1147,11 @@ uint8_t smf_epc_n4_handle_session_deletion_response(
     return OGS_PFCP_CAUSE_REQUEST_ACCEPTED;
 }
 
-void smf_n4_handle_session_report_request(
+/* Returns OGS_PFCP_CAUSE_REQUEST_ACCEPTED on success,
+ * other cause value on failure */
+uint8_t smf_n4_handle_session_report_request(
         smf_sess_t *sess, ogs_pfcp_xact_t *pfcp_xact,
-        ogs_pfcp_message_t *pfcp_message)
+        ogs_pfcp_session_report_request_t *pfcp_req)
 {
     smf_ue_t *smf_ue = NULL;
     smf_bearer_t *qos_flow = NULL;
@@ -1186,13 +1164,9 @@ void smf_n4_handle_session_report_request(
     uint16_t pdr_id = 0;
     unsigned int i;
 
-    ogs_pfcp_session_report_request_t *pfcp_req = NULL;
-
     smf_metrics_inst_global_inc(SMF_METR_GLOB_CTR_SM_N4SESSIONREPORT);
 
     ogs_assert(pfcp_xact);
-    ogs_assert(pfcp_message);
-    pfcp_req = &pfcp_message->pfcp_session_report_request;
     ogs_assert(pfcp_req);
 
     ogs_debug("Session Report Request");
@@ -1210,11 +1184,10 @@ void smf_n4_handle_session_report_request(
     }
 
     if (cause_value != OGS_PFCP_CAUSE_REQUEST_ACCEPTED) {
-        ogs_pfcp_send_error_message(pfcp_xact,
-                sess ? sess->upf_n4_seid : pfcp_message->h.seid,
+        ogs_pfcp_send_error_message(pfcp_xact, 0,
                 OGS_PFCP_SESSION_REPORT_RESPONSE_TYPE,
                 cause_value, 0);
-        return;
+        return cause_value;
     }
 
     ogs_assert(sess);
@@ -1251,22 +1224,20 @@ void smf_n4_handle_session_report_request(
                     if (paging_policy_indication_value) {
                         ogs_warn("Not implement - "
                                 "Paging Policy Indication Value");
-                        ogs_pfcp_send_error_message(pfcp_xact,
-                                sess ? sess->upf_n4_seid : pfcp_message->h.seid,
+                        ogs_pfcp_send_error_message(pfcp_xact, 0,
                                 OGS_PFCP_SESSION_REPORT_RESPONSE_TYPE,
                                 OGS_PFCP_CAUSE_SERVICE_NOT_SUPPORTED, 0);
-                        return;
+                        return OGS_PFCP_CAUSE_SERVICE_NOT_SUPPORTED;
                     }
 
                     if (qfi) {
                         qos_flow = smf_qos_flow_find_by_qfi(sess, qfi);
                         if (!qos_flow) {
                             ogs_error("Cannot find the QoS Flow[%d]", qfi);
-                            ogs_pfcp_send_error_message(pfcp_xact,
-                                sess ? sess->upf_n4_seid : pfcp_message->h.seid,
+                            ogs_pfcp_send_error_message(pfcp_xact, 0,
                                 OGS_PFCP_SESSION_REPORT_RESPONSE_TYPE,
                                 OGS_PFCP_CAUSE_SESSION_CONTEXT_NOT_FOUND, 0);
-                            return;
+                            return OGS_PFCP_CAUSE_SESSION_CONTEXT_NOT_FOUND;
                         }
                     }
                 } else {
@@ -1288,11 +1259,10 @@ void smf_n4_handle_session_report_request(
 
         if (!pdr) {
             ogs_error("No Context");
-            ogs_pfcp_send_error_message(pfcp_xact,
-                    sess ? sess->upf_n4_seid : pfcp_message->h.seid,
+            ogs_pfcp_send_error_message(pfcp_xact, 0,
                     OGS_PFCP_SESSION_REPORT_RESPONSE_TYPE,
                     OGS_PFCP_CAUSE_SESSION_CONTEXT_NOT_FOUND, 0);
-            return;
+            return OGS_PFCP_CAUSE_SESSION_CONTEXT_NOT_FOUND;
         }
 
         switch (sess->up_cnx_state) {
@@ -1364,14 +1334,21 @@ void smf_n4_handle_session_report_request(
             sess->gy.reporting_reason =
                 smf_pfcp_urr_usage_report_trigger2diam_gy_reporting_reason(&rep_trig);
         }
-        switch(smf_use_gy_iface()) {
+        switch (smf_use_gy_iface()) {
         case 1:
-            smf_gy_send_ccr(sess, pfcp_xact,
-                    OGS_DIAM_GY_CC_REQUEST_TYPE_UPDATE_REQUEST);
+            if (!sess->gy.final_unit) {
+                smf_gy_send_ccr(sess, pfcp_xact,
+                        OGS_DIAM_GY_CC_REQUEST_TYPE_UPDATE_REQUEST);
+            } else {
+                ogs_debug("[%s:%s] Rx PFCP report after Gy Final Unit Indication",
+                          smf_ue->imsi_bcd, sess->session.name);
+                /* This effectively triggers session release: */
+                cause_value = OGS_PFCP_CAUSE_NO_RESOURCES_AVAILABLE;
+            }
             break;
         case -1:
             ogs_error("No Gy Diameter Peer");
-            /* TODO: terminate connection */
+            cause_value = OGS_PFCP_CAUSE_NO_RESOURCES_AVAILABLE;
             break;
         /* default: continue below */
         }
@@ -1411,4 +1388,5 @@ void smf_n4_handle_session_report_request(
                     0));
         }
     }
+    return cause_value;
 }
