@@ -206,7 +206,7 @@ int smf_sbi_discover_and_send(
             ogs_assert(true ==
                 ogs_sbi_server_send_error(stream,
                     OGS_SBI_HTTP_STATUS_GATEWAY_TIMEOUT, NULL,
-                    "Cannot discover", smf_ue->supi));
+                    "Cannot discover", smf_ue->supi, NULL));
         return OGS_ERROR;
     }
 
@@ -222,7 +222,7 @@ int smf_sbi_discover_and_send(
             ogs_assert(true ==
                 ogs_sbi_server_send_error(stream,
                     OGS_SBI_HTTP_STATUS_GATEWAY_TIMEOUT, NULL,
-                    "Cannot discover", smf_ue->supi));
+                    "Cannot discover", smf_ue->supi, NULL));
         return r;
     }
 
