@@ -58,6 +58,7 @@ void smf_state_operational(ogs_fsm_t *s, smf_event_t *e)
 
     ogs_gtp_xact_t *gtp_xact = NULL;
     ogs_gtp2_message_t gtp2_message;
+    ogs_gtp2_sender_f_teid_t gtp2_sender_f_teid;
     ogs_gtp1_message_t gtp1_message;
 
     ogs_diam_gx_message_t *gx_message = NULL;
@@ -108,6 +109,8 @@ void smf_state_operational(ogs_fsm_t *s, smf_event_t *e)
         }
         e->gtp2_message = &gtp2_message;
 
+        ogs_gtp2_sender_f_teid(&gtp2_sender_f_teid, &gtp2_message);
+
         rv = ogs_gtp_xact_receive(smf_gnode->gnode, &gtp2_message.h, &gtp_xact);
         if (rv != OGS_OK) {
             ogs_pkbuf_free(recvbuf);
@@ -144,11 +147,21 @@ void smf_state_operational(ogs_fsm_t *s, smf_event_t *e)
             }
             if (!sess) {
                 ogs_error("No Session");
-                ogs_gtp2_send_error_message(gtp_xact, gtp2_message.h.teid,
+                ogs_gtp2_send_error_message(gtp_xact,
+                        gtp2_sender_f_teid.teid_presence == true ?
+                            gtp2_sender_f_teid.teid : 0,
                         OGS_GTP2_CREATE_SESSION_RESPONSE_TYPE,
                         OGS_GTP2_CAUSE_CONTEXT_NOT_FOUND);
                 break;
             }
+
+            if (gtp2_sender_f_teid.teid_presence == true)
+                sess->sgw_s5c_teid = gtp2_sender_f_teid.teid;
+
+            ogs_debug("    SGW_S5C_TEID[0x%x], Sender F-TEID(%d)[0x%x]",
+                    sess->sgw_s5c_teid,
+                    gtp2_sender_f_teid.teid_presence, gtp2_sender_f_teid.teid);
+
             e->sess = sess;
             ogs_fsm_dispatch(&sess->sm, e);
             break;
@@ -158,28 +171,43 @@ void smf_state_operational(ogs_fsm_t *s, smf_event_t *e)
             smf_metrics_inst_gtp_node_inc(smf_gnode->metrics, SMF_METR_GTP_NODE_CTR_S5C_RX_DELETESESSIONREQ);
             if (!sess) {
                 ogs_error("No Session");
-                ogs_gtp2_send_error_message(gtp_xact, gtp2_message.h.teid,
+                ogs_gtp2_send_error_message(gtp_xact,
+                        gtp2_sender_f_teid.teid_presence == true ?
+                            gtp2_sender_f_teid.teid : 0,
                         OGS_GTP2_DELETE_SESSION_RESPONSE_TYPE,
                         OGS_GTP2_CAUSE_CONTEXT_NOT_FOUND);
                 break;
             }
+            if (gtp2_sender_f_teid.teid_presence == true) {
+                if (sess->sgw_s5c_teid != gtp2_sender_f_teid.teid) {
+                    ogs_error("Invalid Sender F-TEID [0x%x != 0x%x]",
+                        sess->sgw_s5c_teid, gtp2_sender_f_teid.teid);
+                    ogs_gtp2_send_error_message(gtp_xact,
+                            gtp2_sender_f_teid.teid_presence == true ?
+                                gtp2_sender_f_teid.teid : 0,
+                            OGS_GTP2_DELETE_SESSION_RESPONSE_TYPE,
+                            OGS_GTP2_CAUSE_INVALID_MESSAGE_FORMAT);
+                    break;
+                }
+            }
             e->sess = sess;
             ogs_fsm_dispatch(&sess->sm, e);
             break;
         case OGS_GTP2_MODIFY_BEARER_REQUEST_TYPE:
             if (!gtp2_message.h.teid_presence) ogs_error("No TEID");
             smf_s5c_handle_modify_bearer_request(
-                sess, gtp_xact, recvbuf, &gtp2_message);
+                sess, gtp_xact, recvbuf,
+                &gtp2_message.modify_bearer_request, &gtp2_sender_f_teid);
             break;
         case OGS_GTP2_CREATE_BEARER_RESPONSE_TYPE:
             if (!gtp2_message.h.teid_presence) ogs_error("No TEID");
             smf_s5c_handle_create_bearer_response(
-                sess, gtp_xact, &gtp2_message);
+                sess, gtp_xact, &gtp2_message.create_bearer_response);
             break;
         case OGS_GTP2_UPDATE_BEARER_RESPONSE_TYPE:
             if (!gtp2_message.h.teid_presence) ogs_error("No TEID");
             smf_s5c_handle_update_bearer_response(
-                sess, gtp_xact, &gtp2_message);
+                sess, gtp_xact, &gtp2_message.update_bearer_response);
             break;
         case OGS_GTP2_DELETE_BEARER_RESPONSE_TYPE:
             if (!gtp2_message.h.teid_presence) ogs_error("No TEID");
@@ -194,7 +222,8 @@ void smf_state_operational(ogs_fsm_t *s, smf_event_t *e)
         case OGS_GTP2_BEARER_RESOURCE_COMMAND_TYPE:
             if (!gtp2_message.h.teid_presence) ogs_error("No TEID");
             smf_s5c_handle_bearer_resource_command(
-                sess, gtp_xact, &gtp2_message);
+                sess, gtp_xact,
+                &gtp2_message.bearer_resource_command, &gtp2_sender_f_teid);
             break;
         default:
             ogs_warn("Not implemented(type:%d)", gtp2_message.h.type);
