@@ -72,7 +72,7 @@ void udr_state_operational(ogs_fsm_t *s, udr_event_t *e)
             ogs_assert(true ==
                 ogs_sbi_server_send_error(
                     stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
-                    NULL, "cannot parse HTTP message", NULL));
+                    NULL, "cannot parse HTTP message", NULL, NULL));
             break;
         }
 
@@ -81,7 +81,7 @@ void udr_state_operational(ogs_fsm_t *s, udr_event_t *e)
             ogs_assert(true ==
                 ogs_sbi_server_send_error(
                     stream, OGS_SBI_HTTP_STATUS_BAD_REQUEST,
-                    &message, "Not supported version", NULL));
+                    &message, "Not supported version", NULL, NULL));
             ogs_sbi_message_free(&message);
             break;
         }
@@ -102,7 +102,8 @@ void udr_state_operational(ogs_fsm_t *s, udr_event_t *e)
                     ogs_assert(true ==
                         ogs_sbi_server_send_error(stream,
                             OGS_SBI_HTTP_STATUS_FORBIDDEN,
-                            &message, "Invalid HTTP method", message.h.method));
+                            &message, "Invalid HTTP method", message.h.method,
+                            NULL));
                 END
                 break;
 
@@ -113,7 +114,7 @@ void udr_state_operational(ogs_fsm_t *s, udr_event_t *e)
                     ogs_sbi_server_send_error(stream,
                         OGS_SBI_HTTP_STATUS_BAD_REQUEST, &message,
                         "Unknown resource name",
-                        message.h.resource.component[0]));
+                        message.h.resource.component[0], NULL));
             END
             break;
 
@@ -145,7 +146,7 @@ void udr_state_operational(ogs_fsm_t *s, udr_event_t *e)
                                 ogs_sbi_server_send_error(stream,
                                     OGS_SBI_HTTP_STATUS_FORBIDDEN,
                                     &message, "Invalid HTTP method",
-                                    message.h.method));
+                                    message.h.method, NULL));
                         END
                         break;
                     DEFAULT
@@ -155,7 +156,7 @@ void udr_state_operational(ogs_fsm_t *s, udr_event_t *e)
                             ogs_sbi_server_send_error(stream,
                                 OGS_SBI_HTTP_STATUS_BAD_REQUEST,
                                 &message, "Unknown resource name",
-                                message.h.resource.component[2]));
+                                message.h.resource.component[2], NULL));
                     END
                 END
                 break;
@@ -171,7 +172,7 @@ void udr_state_operational(ogs_fsm_t *s, udr_event_t *e)
                     ogs_sbi_server_send_error(stream,
                         OGS_SBI_HTTP_STATUS_BAD_REQUEST,
                         &message, "Unknown resource name",
-                        message.h.resource.component[0]));
+                        message.h.resource.component[0], NULL));
             END
             break;
 
@@ -180,7 +181,8 @@ void udr_state_operational(ogs_fsm_t *s, udr_event_t *e)
             ogs_assert(true ==
                 ogs_sbi_server_send_error(stream,
                     OGS_SBI_HTTP_STATUS_BAD_REQUEST, &message,
-                    "Invalid API name", message.h.resource.component[0]));
+                    "Invalid API name", message.h.resource.component[0],
+                    NULL));
         END
 
         /* In lib/sbi/server.c, notify_completed() releases 'request' buffer. */
