@@ -284,16 +284,20 @@ void upf_pfcp_state_associated(ogs_fsm_t *s, upf_event_t *e)
             sess = upf_sess_add_by_message(message);
             if (sess)
                 OGS_SETUP_PFCP_NODE(sess, node);
-            upf_n4_handle_session_establishment_request(sess, xact, message);
+            upf_n4_handle_session_establishment_request(
+                sess, xact, &message->pfcp_session_establishment_request);
             break;
         case OGS_PFCP_SESSION_MODIFICATION_REQUEST_TYPE:
-            upf_n4_handle_session_modification_request(sess, xact, message);
+            upf_n4_handle_session_modification_request(
+                sess, xact, &message->pfcp_session_modification_request);
             break;
         case OGS_PFCP_SESSION_DELETION_REQUEST_TYPE:
-            upf_n4_handle_session_deletion_request(sess, xact, message);
+            upf_n4_handle_session_deletion_request(
+                sess, xact, &message->pfcp_session_deletion_request);
             break;
         case OGS_PFCP_SESSION_REPORT_RESPONSE_TYPE:
-            upf_n4_handle_session_report_response(sess, xact, message);
+            upf_n4_handle_session_report_response(
+                sess, xact, &message->pfcp_session_report_response);
             break;
         default:
             ogs_error("Not implemented PFCP message type[%d]",
