@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019 by Sukchan Lee <acetcom@gmail.com>
+ * Copyright (C) 2019-2022 by Sukchan Lee <acetcom@gmail.com>
  *
  * This file is part of Open5GS.
  *
@@ -39,7 +39,8 @@ typedef enum {
 
 const char *af_local_get_name(af_local_e id);
 
-void af_local_discover_and_send(OpenAPI_nf_type_e target_nf_type,
+void af_local_discover_and_send(
+        ogs_sbi_service_type_e service_type,
         af_sess_t *sess, void *data,
         ogs_sbi_request_t *(*build)(af_sess_t *sess, void *data));
 
