@@ -63,7 +63,13 @@ ogs_pkbuf_t *testesm_build_pdn_connectivity_request(
     }
 
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
+
+    if (!sess->pti) {
+        ogs_error("PTI should be not NULL in PDU Connectivity Request");
+        return NULL;
+    }
     message.esm.h.procedure_transaction_identity = sess->pti;
+
     message.esm.h.message_type = OGS_NAS_EPS_PDN_CONNECTIVITY_REQUEST;
 
     request_type->type = OGS_NAS_EPS_PDN_TYPE_IPV4V6;
@@ -136,7 +142,13 @@ ogs_pkbuf_t *testesm_build_pdn_disconnect_request(test_sess_t *sess)
     message.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_EMM;
 
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
+
+    if (!sess->pti) {
+        ogs_error("PTI should be not NULL in PDU Disonnectivity Request");
+        return NULL;
+    }
     message.esm.h.procedure_transaction_identity = sess->pti;
+
     message.esm.h.message_type = OGS_NAS_EPS_PDN_DISCONNECT_REQUEST;
 
     linked_eps_bearer_identity->eps_bearer_identity = bearer->ebi;
@@ -194,7 +206,13 @@ ogs_pkbuf_t *testesm_build_esm_information_response(test_sess_t *sess)
     message.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_EMM;
 
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
+
+    if (!sess->pti) {
+        ogs_error("PTI should be not 0 in ESM Information Response");
+        return NULL;
+    }
     message.esm.h.procedure_transaction_identity = sess->pti;
+
     message.esm.h.message_type = OGS_NAS_EPS_ESM_INFORMATION_RESPONSE;
 
     esm_information_response->presencemask |= OGS_NAS_EPS_ESM_INFORMATION_RESPONSE_ACCESS_POINT_NAME_PRESENT;
@@ -254,6 +272,7 @@ ogs_pkbuf_t *testesm_build_activate_default_eps_bearer_context_accept(
 
     message.esm.h.eps_bearer_identity = bearer->ebi;
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
+    message.esm.h.procedure_transaction_identity = sess->pti = 0;
     message.esm.h.message_type =
         OGS_NAS_EPS_ACTIVATE_DEFAULT_EPS_BEARER_CONTEXT_ACCEPT;
 
@@ -289,6 +308,7 @@ ogs_pkbuf_t *testesm_build_activate_dedicated_eps_bearer_context_accept(
 
     message.esm.h.eps_bearer_identity = bearer->ebi;
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
+    message.esm.h.procedure_transaction_identity = sess->pti = 0;
     message.esm.h.message_type =
         OGS_NAS_EPS_ACTIVATE_DEDICATED_EPS_BEARER_CONTEXT_ACCEPT;
 
@@ -321,6 +341,7 @@ ogs_pkbuf_t *testesm_build_activate_dedicated_eps_bearer_context_reject(
 
     message.esm.h.eps_bearer_identity = bearer->ebi;
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
+    message.esm.h.procedure_transaction_identity = sess->pti = 0;
     message.esm.h.message_type =
         OGS_NAS_EPS_ACTIVATE_DEDICATED_EPS_BEARER_CONTEXT_REJECT;
 
@@ -352,7 +373,7 @@ ogs_pkbuf_t *testesm_build_modify_eps_bearer_context_accept(
 
     message.esm.h.eps_bearer_identity = bearer->ebi;
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
-    message.esm.h.procedure_transaction_identity = sess->pti;
+    message.esm.h.procedure_transaction_identity = sess->pti = 0;
     message.esm.h.message_type = OGS_NAS_EPS_MODIFY_EPS_BEARER_CONTEXT_ACCEPT;
 
     return test_nas_eps_security_encode(test_ue, &message);
@@ -381,6 +402,7 @@ ogs_pkbuf_t *testesm_build_deactivate_eps_bearer_context_accept(
 
     message.esm.h.eps_bearer_identity = bearer->ebi;
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
+    message.esm.h.procedure_transaction_identity = sess->pti = 0;
     message.esm.h.message_type =
         OGS_NAS_EPS_DEACTIVATE_EPS_BEARER_CONTEXT_ACCEPT;
 
@@ -422,7 +444,13 @@ ogs_pkbuf_t *testesm_build_bearer_resource_allocation_request(
     message.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_EMM;
 
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
+
+    if (!sess->pti) {
+        ogs_error("PTI should be not 0 in Bearer Resource Allocation Request");
+        return NULL;
+    }
     message.esm.h.procedure_transaction_identity = sess->pti;
+
     message.esm.h.message_type = OGS_NAS_EPS_BEARER_RESOURCE_ALLOCATION_REQUEST;
 
     linked_eps_bearer_identity->eps_bearer_identity = bearer->ebi;
@@ -473,7 +501,14 @@ ogs_pkbuf_t *testesm_build_bearer_resource_modification_request(
     message.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_EMM;
 
     message.esm.h.protocol_discriminator = OGS_NAS_PROTOCOL_DISCRIMINATOR_ESM;
+
+    if (!sess->pti) {
+        ogs_error("PTI should be not 0 "
+                "in Bearer Resource Modification Request");
+        return NULL;
+    }
     message.esm.h.procedure_transaction_identity = sess->pti;
+
     message.esm.h.message_type =
         OGS_NAS_EPS_BEARER_RESOURCE_MODIFICATION_REQUEST;
 
