@@ -82,9 +82,7 @@ static void test2_main(void *data)
 
     size = ogs_sctp_recvdata(sctp, str, STRLEN, &from, &sinfo);
     ABTS_INT_EQUAL(tc, strlen(DATASTR), size);
-#if !HAVE_USRSCTP /* FIXME : USRSCTP is not working */
     ABTS_INT_EQUAL(tc, PPID, sinfo.ppid);
-#endif
 
     ogs_sctp_destroy(sctp);
     rv = ogs_freeaddrinfo(addr);
@@ -171,9 +169,7 @@ static void test3_func(abts_case *tc, void *data)
 
     size = ogs_sctp_recvdata(sctp, str, STRLEN, &from, &sinfo);
     ABTS_INT_EQUAL(tc, strlen(DATASTR), size);
-#if !HAVE_USRSCTP /* FIXME : USRSCTP is not working */
     ABTS_INT_EQUAL(tc, PPID, sinfo.ppid);
-#endif
     
     ogs_thread_destroy(test3_thread);
 
@@ -204,7 +200,7 @@ static void test4_main(void *data)
 
     size = ogs_sctp_recvdata(sctp, str, STRLEN, NULL, &sinfo);
     ABTS_INT_EQUAL(tc, strlen(DATASTR), size);
-#if !HAVE_USRSCTP /* FIXME : USRSCTP is not working */
+#if !HAVE_USRSCTP
     ABTS_INT_EQUAL(tc, PPID, sinfo.ppid);
 #endif
 
@@ -235,9 +231,7 @@ static void test4_func(abts_case *tc, void *data)
     size = ogs_sctp_recvdata(sctp, str, STRLEN, &from, &sinfo);
     ABTS_INT_EQUAL(tc, strlen(DATASTR), size);
     ABTS_STR_EQUAL(tc, "::1", OGS_ADDR(&from, buf));
-#if !HAVE_USRSCTP /* FIXME : USRSCTP is not working */
     ABTS_INT_EQUAL(tc, PPID, sinfo.ppid);
-#endif
 
     size = ogs_sctp_sendmsg(sctp, DATASTR, strlen(DATASTR), &from, PPID, 0);
     ABTS_INT_EQUAL(tc, strlen(DATASTR), size);
@@ -273,24 +267,16 @@ static void test5_main(void *data)
     ABTS_INT_EQUAL(tc, OGS_OK, rv);
     rv = ogs_sctp_connect(sctp, addr);
     ABTS_INT_EQUAL(tc, OGS_OK, rv);
+    size = ogs_sctp_sendmsg(sctp, DATASTR, strlen(DATASTR), addr, PPID, 0);
+    ABTS_INT_EQUAL(tc, strlen(DATASTR), size);
+
     rv = ogs_freeaddrinfo(addr);
     ABTS_INT_EQUAL(tc, OGS_OK, rv);
-#if !HAVE_USRSCTP /* FIXME : libusrsctp 0.9.3.0 does not support remote_addr */
-    remote_addr = &sctp->remote_addr;
-    ABTS_STR_EQUAL(tc, "::1", OGS_ADDR(remote_addr, buf));
-
-    size = ogs_sctp_sendmsg(sctp, DATASTR, strlen(DATASTR),
-            remote_addr, PPID, 0);
-#else
-    size = ogs_sctp_sendmsg(sctp, DATASTR, strlen(DATASTR),
-            addr, PPID, 0);
-#endif
-    ABTS_INT_EQUAL(tc, strlen(DATASTR), size);
 
     size = ogs_sctp_recvdata(sctp, str, STRLEN, &from, &sinfo);
     ABTS_INT_EQUAL(tc, strlen(DATASTR), size);
     ABTS_STR_EQUAL(tc, "::1", OGS_ADDR(&from, buf));
-#if !HAVE_USRSCTP /* FIXME : USRSCTP is not working */
+#if !HAVE_USRSCTP
     ABTS_INT_EQUAL(tc, PPID, sinfo.ppid);
 #endif
 
@@ -320,9 +306,7 @@ static void test5_func(abts_case *tc, void *data)
     size = ogs_sctp_recvdata(sctp, str, STRLEN, &from, &sinfo);
     ABTS_INT_EQUAL(tc, strlen(DATASTR), size);
     ABTS_STR_EQUAL(tc, "::1", OGS_ADDR(&from, buf));
-#if !HAVE_USRSCTP /* FIXME : USRSCTP is not working */
     ABTS_INT_EQUAL(tc, PPID, sinfo.ppid);
-#endif
 
     size = ogs_sctp_sendmsg(sctp, DATASTR, strlen(DATASTR), &from,
             sinfo.ppid, 0);
