@@ -48,14 +48,10 @@ static void test1_func(abts_case *tc, void *data)
     mobile_identity_suci.routing_indicator2 = 0xf;
     mobile_identity_suci.routing_indicator3 = 0xf;
     mobile_identity_suci.routing_indicator4 = 0xf;
-    mobile_identity_suci.protection_scheme_id = OGS_NAS_5GS_NULL_SCHEME;
+    mobile_identity_suci.protection_scheme_id = OGS_PROTECTION_SCHEME_NULL;
     mobile_identity_suci.home_network_pki_value = 0;
-    mobile_identity_suci.scheme_output[0] = 0;
-    mobile_identity_suci.scheme_output[1] = 0;
-    mobile_identity_suci.scheme_output[2] = 0x47;
-    mobile_identity_suci.scheme_output[3] = 0x78;
 
-    test_ue = test_ue_add_by_suci(&mobile_identity_suci, 12);
+    test_ue = test_ue_add_by_suci(&mobile_identity_suci, "00004778");
     ogs_assert(test_ue);
 
     test_ue->nr_cgi.cell_id = 0x40001;
@@ -353,14 +349,10 @@ static void test2_func(abts_case *tc, void *data)
     mobile_identity_suci.routing_indicator2 = 0xf;
     mobile_identity_suci.routing_indicator3 = 0xf;
     mobile_identity_suci.routing_indicator4 = 0xf;
-    mobile_identity_suci.protection_scheme_id = OGS_NAS_5GS_NULL_SCHEME;
+    mobile_identity_suci.protection_scheme_id = OGS_PROTECTION_SCHEME_NULL;
     mobile_identity_suci.home_network_pki_value = 0;
-    mobile_identity_suci.scheme_output[0] = 0;
-    mobile_identity_suci.scheme_output[1] = 0;
-    mobile_identity_suci.scheme_output[2] = 0x47;
-    mobile_identity_suci.scheme_output[3] = 0x78;
 
-    test_ue = test_ue_add_by_suci(&mobile_identity_suci, 12);
+    test_ue = test_ue_add_by_suci(&mobile_identity_suci, "00004778");
     ogs_assert(test_ue);
 
     test_ue->nr_cgi.cell_id = 0x40001;
